@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,13 +18,21 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 # pylint: disable=W0622
 """This module contains an object that represents a Telegram CallbackQuery"""
-from typing import TYPE_CHECKING, Any, List, Optional, Union
+from typing import TYPE_CHECKING, Any, List, Optional, Union, Tuple, ClassVar
 
-from telegram import Message, TelegramObject, User
-from telegram.utils.types import JSONDict
+from telegram import Message, TelegramObject, User, Location, ReplyMarkup, constants
+from telegram.utils.helpers import DEFAULT_NONE
+from telegram.utils.types import JSONDict, ODVInput, DVInput
 
 if TYPE_CHECKING:
-    from telegram import Bot, GameHighScore, InlineKeyboardMarkup, MessageId
+    from telegram import (
+        Bot,
+        GameHighScore,
+        InlineKeyboardMarkup,
+        MessageId,
+        InputMedia,
+        MessageEntity,
+    )
 
 
 class CallbackQuery(TelegramObject):
@@ -41,19 +49,10 @@ class CallbackQuery(TelegramObject):
     Note:
         * In Python `from` is a reserved word, use `from_user` instead.
         * Exactly one of the fields :attr:`data` or :attr:`game_short_name` will be present.
-
-    Attributes:
-        id (:obj:`str`): Unique identifier for this query.
-        from_user (:class:`telegram.User`): Sender.
-        chat_instance (:obj:`str`): Global identifier, uniquely corresponding to the chat to which
-            the message with the callback button was sent.
-        message (:class:`telegram.Message`): Optional. Message with the callback button that
-            originated the query.
-        data (:obj:`str`): Optional. Data associated with the callback button.
-        inline_message_id (:obj:`str`): Optional. Identifier of the message sent via the bot in
-                inline mode, that originated the query.
-        game_short_name (:obj:`str`): Optional. Short name of a Game to be returned.
-        bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
+        * After the user presses an inline button, Telegram clients will display a progress bar
+          until you call :attr:`answer`. It is, therefore, necessary to react
+          by calling :attr:`telegram.Bot.answer_callback_query` even if no notification to the user
+          is needed (e.g., without specifying any of the optional parameters).
 
     Args:
         id (:obj:`str`): Unique identifier for this query.
@@ -71,11 +70,18 @@ class CallbackQuery(TelegramObject):
             the unique identifier for the game
         bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
 
-    Note:
-        After the user presses an inline button, Telegram clients will display a progress bar
-        until you call :attr:`answer`. It is, therefore, necessary to react
-        by calling :attr:`telegram.Bot.answer_callback_query` even if no notification to the user
-        is needed (e.g., without specifying any of the optional parameters).
+    Attributes:
+        id (:obj:`str`): Unique identifier for this query.
+        from_user (:class:`telegram.User`): Sender.
+        chat_instance (:obj:`str`): Global identifier, uniquely corresponding to the chat to which
+            the message with the callback button was sent.
+        message (:class:`telegram.Message`): Optional. Message with the callback button that
+            originated the query.
+        data (:obj:`str`): Optional. Data associated with the callback button.
+        inline_message_id (:obj:`str`): Optional. Identifier of the message sent via the bot in
+                inline mode, that originated the query.
+        game_short_name (:obj:`str`): Optional. Short name of a Game to be returned.
+        bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
 
     """
 
@@ -117,18 +123,46 @@ class CallbackQuery(TelegramObject):
 
         return cls(bot=bot, **data)
 
-    def answer(self, *args: Any, **kwargs: Any) -> bool:
+    def answer(
+        self,
+        text: str = None,
+        show_alert: bool = False,
+        url: str = None,
+        cache_time: int = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
         """Shortcut for::
 
             bot.answer_callback_query(update.callback_query.id, *args, **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.answer_callback_query`.
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
         """
-        return self.bot.answer_callback_query(self.id, *args, **kwargs)
+        return self.bot.answer_callback_query(
+            callback_query_id=self.id,
+            text=text,
+            show_alert=show_alert,
+            url=url,
+            cache_time=cache_time,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def edit_message_text(self, text: str, *args: Any, **kwargs: Any) -> Union[Message, bool]:
+    def edit_message_text(
+        self,
+        text: str,
+        parse_mode: ODVInput[str] = DEFAULT_NONE,
+        disable_web_page_preview: ODVInput[bool] = DEFAULT_NONE,
+        reply_markup: 'InlineKeyboardMarkup' = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+        entities: Union[List['MessageEntity'], Tuple['MessageEntity', ...]] = None,
+    ) -> Union[Message, bool]:
         """Shortcut for either::
 
             update.callback_query.message.edit_text(text, *args, **kwargs)
@@ -138,6 +172,9 @@ class CallbackQuery(TelegramObject):
             bot.edit_message_text(text, inline_message_id=update.callback_query.inline_message_id,
                                 *args, **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.edit_message_text`.
+
         Returns:
             :class:`telegram.Message`: On success, if edited message is sent by the bot, the
             edited Message is returned, otherwise :obj:`True` is returned.
@@ -145,12 +182,35 @@ class CallbackQuery(TelegramObject):
         """
         if self.inline_message_id:
             return self.bot.edit_message_text(
-                text, inline_message_id=self.inline_message_id, *args, **kwargs
+                inline_message_id=self.inline_message_id,
+                text=text,
+                parse_mode=parse_mode,
+                disable_web_page_preview=disable_web_page_preview,
+                reply_markup=reply_markup,
+                timeout=timeout,
+                api_kwargs=api_kwargs,
+                entities=entities,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.edit_text(text, *args, **kwargs)
+        return self.message.edit_text(
+            text=text,
+            parse_mode=parse_mode,
+            disable_web_page_preview=disable_web_page_preview,
+            reply_markup=reply_markup,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+            entities=entities,
+        )
 
     def edit_message_caption(
-        self, caption: str, *args: Any, **kwargs: Any
+        self,
+        caption: str = None,
+        reply_markup: 'InlineKeyboardMarkup' = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        parse_mode: ODVInput[str] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+        caption_entities: Union[List['MessageEntity'], Tuple['MessageEntity', ...]] = None,
     ) -> Union[Message, bool]:
         """Shortcut for either::
 
@@ -162,6 +222,9 @@ class CallbackQuery(TelegramObject):
                                     inline_message_id=update.callback_query.inline_message_id,
                                    *args, **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.edit_message_caption`.
+
         Returns:
             :class:`telegram.Message`: On success, if edited message is sent by the bot, the
             edited Message is returned, otherwise :obj:`True` is returned.
@@ -169,12 +232,30 @@ class CallbackQuery(TelegramObject):
         """
         if self.inline_message_id:
             return self.bot.edit_message_caption(
-                caption=caption, inline_message_id=self.inline_message_id, *args, **kwargs
+                caption=caption,
+                inline_message_id=self.inline_message_id,
+                reply_markup=reply_markup,
+                timeout=timeout,
+                parse_mode=parse_mode,
+                api_kwargs=api_kwargs,
+                caption_entities=caption_entities,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.edit_caption(caption=caption, *args, **kwargs)
+        return self.message.edit_caption(
+            caption=caption,
+            reply_markup=reply_markup,
+            timeout=timeout,
+            parse_mode=parse_mode,
+            api_kwargs=api_kwargs,
+            caption_entities=caption_entities,
+        )
 
     def edit_message_reply_markup(
-        self, reply_markup: 'InlineKeyboardMarkup', *args: Any, **kwargs: Any
+        self,
+        reply_markup: Optional['InlineKeyboardMarkup'] = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
     ) -> Union[Message, bool]:
         """Shortcut for either::
 
@@ -193,6 +274,9 @@ class CallbackQuery(TelegramObject):
                 **kwargs
             )
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.edit_message_reply_markup`.
+
         Returns:
             :class:`telegram.Message`: On success, if edited message is sent by the bot, the
             edited Message is returned, otherwise :obj:`True` is returned.
@@ -202,12 +286,24 @@ class CallbackQuery(TelegramObject):
             return self.bot.edit_message_reply_markup(
                 reply_markup=reply_markup,
                 inline_message_id=self.inline_message_id,
-                *args,
-                **kwargs,
+                timeout=timeout,
+                api_kwargs=api_kwargs,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.edit_reply_markup(reply_markup=reply_markup, *args, **kwargs)
+        return self.message.edit_reply_markup(
+            reply_markup=reply_markup,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def edit_message_media(self, *args: Any, **kwargs: Any) -> Union[Message, bool]:
+    def edit_message_media(
+        self,
+        media: 'InputMedia' = None,
+        reply_markup: 'InlineKeyboardMarkup' = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> Union[Message, bool]:
         """Shortcut for either::
 
             update.callback_query.message.edit_media(*args, **kwargs)
@@ -217,6 +313,9 @@ class CallbackQuery(TelegramObject):
             bot.edit_message_media(inline_message_id=update.callback_query.inline_message_id,
                                    *args, **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.edit_message_media`.
+
         Returns:
             :class:`telegram.Message`: On success, if edited message is sent by the bot, the
             edited Message is returned, otherwise :obj:`True` is returned.
@@ -224,11 +323,33 @@ class CallbackQuery(TelegramObject):
         """
         if self.inline_message_id:
             return self.bot.edit_message_media(
-                inline_message_id=self.inline_message_id, *args, **kwargs
+                inline_message_id=self.inline_message_id,
+                media=media,
+                reply_markup=reply_markup,
+                timeout=timeout,
+                api_kwargs=api_kwargs,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.edit_media(*args, **kwargs)
+        return self.message.edit_media(
+            media=media,
+            reply_markup=reply_markup,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def edit_message_live_location(self, *args: Any, **kwargs: Any) -> Union[Message, bool]:
+    def edit_message_live_location(
+        self,
+        latitude: float = None,
+        longitude: float = None,
+        location: Location = None,
+        reply_markup: 'InlineKeyboardMarkup' = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+        horizontal_accuracy: float = None,
+        heading: int = None,
+        proximity_alert_radius: int = None,
+    ) -> Union[Message, bool]:
         """Shortcut for either::
 
             update.callback_query.message.edit_live_location(*args, **kwargs)
@@ -240,6 +361,9 @@ class CallbackQuery(TelegramObject):
                 *args, **kwargs
             )
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.edit_message_live_location`.
+
         Returns:
             :class:`telegram.Message`: On success, if edited message is sent by the bot, the
             edited Message is returned, otherwise :obj:`True` is returned.
@@ -247,11 +371,37 @@ class CallbackQuery(TelegramObject):
         """
         if self.inline_message_id:
             return self.bot.edit_message_live_location(
-                inline_message_id=self.inline_message_id, *args, **kwargs
+                inline_message_id=self.inline_message_id,
+                latitude=latitude,
+                longitude=longitude,
+                location=location,
+                reply_markup=reply_markup,
+                timeout=timeout,
+                api_kwargs=api_kwargs,
+                horizontal_accuracy=horizontal_accuracy,
+                heading=heading,
+                proximity_alert_radius=proximity_alert_radius,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.edit_live_location(*args, **kwargs)
+        return self.message.edit_live_location(
+            latitude=latitude,
+            longitude=longitude,
+            location=location,
+            reply_markup=reply_markup,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+            horizontal_accuracy=horizontal_accuracy,
+            heading=heading,
+            proximity_alert_radius=proximity_alert_radius,
+        )
 
-    def stop_message_live_location(self, *args: Any, **kwargs: Any) -> Union[Message, bool]:
+    def stop_message_live_location(
+        self,
+        reply_markup: 'InlineKeyboardMarkup' = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> Union[Message, bool]:
         """Shortcut for either::
 
             update.callback_query.message.stop_live_location(*args, **kwargs)
@@ -263,6 +413,9 @@ class CallbackQuery(TelegramObject):
                 *args, **kwargs
             )
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.stop_message_live_location`.
+
         Returns:
             :class:`telegram.Message`: On success, if edited message is sent by the bot, the
             edited Message is returned, otherwise :obj:`True` is returned.
@@ -270,11 +423,28 @@ class CallbackQuery(TelegramObject):
         """
         if self.inline_message_id:
             return self.bot.stop_message_live_location(
-                inline_message_id=self.inline_message_id, *args, **kwargs
+                inline_message_id=self.inline_message_id,
+                reply_markup=reply_markup,
+                timeout=timeout,
+                api_kwargs=api_kwargs,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.stop_live_location(*args, **kwargs)
+        return self.message.stop_live_location(
+            reply_markup=reply_markup,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def set_game_score(self, *args: Any, **kwargs: Any) -> Union[Message, bool]:
+    def set_game_score(
+        self,
+        user_id: Union[int, str],
+        score: int,
+        force: bool = None,
+        disable_edit_message: bool = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> Union[Message, bool]:
         """Shortcut for either::
 
            update.callback_query.message.set_game_score(*args, **kwargs)
@@ -284,6 +454,9 @@ class CallbackQuery(TelegramObject):
             bot.set_game_score(inline_message_id=update.callback_query.inline_message_id,
                                *args, **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.set_game_score`.
+
         Returns:
             :class:`telegram.Message`: On success, if edited message is sent by the bot, the
             edited Message is returned, otherwise :obj:`True` is returned.
@@ -291,11 +464,31 @@ class CallbackQuery(TelegramObject):
         """
         if self.inline_message_id:
             return self.bot.set_game_score(
-                inline_message_id=self.inline_message_id, *args, **kwargs
+                inline_message_id=self.inline_message_id,
+                user_id=user_id,
+                score=score,
+                force=force,
+                disable_edit_message=disable_edit_message,
+                timeout=timeout,
+                api_kwargs=api_kwargs,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.set_game_score(*args, **kwargs)
+        return self.message.set_game_score(
+            user_id=user_id,
+            score=score,
+            force=force,
+            disable_edit_message=disable_edit_message,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def get_game_high_scores(self, *args: Any, **kwargs: Any) -> List['GameHighScore']:
+    def get_game_high_scores(
+        self,
+        user_id: Union[int, str],
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> List['GameHighScore']:
         """Shortcut for either::
 
             update.callback_query.message.get_game_high_score(*args, **kwargs)
@@ -305,28 +498,55 @@ class CallbackQuery(TelegramObject):
             bot.get_game_high_scores(inline_message_id=update.callback_query.inline_message_id,
                                      *args, **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.get_game_high_scores`.
+
         Returns:
             List[:class:`telegram.GameHighScore`]
 
         """
         if self.inline_message_id:
             return self.bot.get_game_high_scores(
-                inline_message_id=self.inline_message_id, *args, **kwargs
+                inline_message_id=self.inline_message_id,
+                user_id=user_id,
+                timeout=timeout,
+                api_kwargs=api_kwargs,
+                chat_id=None,
+                message_id=None,
             )
-        return self.message.get_game_high_scores(*args, **kwargs)
+        return self.message.get_game_high_scores(
+            user_id=user_id,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def delete_message(self, *args: Any, **kwargs: Any) -> Union[Message, bool]:
+    def delete_message(
+        self,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
         """Shortcut for::
 
             update.callback_query.message.delete(*args, **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.delete_message`.
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
         """
-        return self.message.delete(*args, **kwargs)
+        return self.message.delete(
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def pin_message(self, *args: Any, **kwargs: Any) -> bool:
+    def pin_message(
+        self,
+        disable_notification: ODVInput[bool] = DEFAULT_NONE,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
         """Shortcut for::
 
              bot.pin_chat_message(chat_id=message.chat_id,
@@ -334,13 +554,24 @@ class CallbackQuery(TelegramObject):
                                   *args,
                                   **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.pin_chat_message`.
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
         """
-        return self.message.pin(*args, **kwargs)
+        return self.message.pin(
+            disable_notification=disable_notification,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def unpin_message(self, *args: Any, **kwargs: Any) -> bool:
+    def unpin_message(
+        self,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
         """Shortcut for::
 
              bot.unpin_chat_message(chat_id=message.chat_id,
@@ -348,13 +579,31 @@ class CallbackQuery(TelegramObject):
                                     *args,
                                     **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.unpin_chat_message`.
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
         """
-        return self.message.unpin(*args, **kwargs)
+        return self.message.unpin(
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
 
-    def copy_message(self, chat_id: int, *args: Any, **kwargs: Any) -> 'MessageId':
+    def copy_message(
+        self,
+        chat_id: Union[int, str],
+        caption: str = None,
+        parse_mode: ODVInput[str] = DEFAULT_NONE,
+        caption_entities: Union[Tuple['MessageEntity', ...], List['MessageEntity']] = None,
+        disable_notification: DVInput[bool] = DEFAULT_NONE,
+        reply_to_message_id: Union[int, str] = None,
+        allow_sending_without_reply: DVInput[bool] = DEFAULT_NONE,
+        reply_markup: ReplyMarkup = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> 'MessageId':
         """Shortcut for::
 
             update.callback_query.message.copy(
@@ -364,8 +613,29 @@ class CallbackQuery(TelegramObject):
                 *args,
                 **kwargs)
 
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.copy_message`.
+
         Returns:
             :class:`telegram.MessageId`: On success, returns the MessageId of the sent message.
 
         """
-        return self.message.copy(chat_id, *args, **kwargs)
+        return self.message.copy(
+            chat_id=chat_id,
+            caption=caption,
+            parse_mode=parse_mode,
+            caption_entities=caption_entities,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            allow_sending_without_reply=allow_sending_without_reply,
+            reply_markup=reply_markup,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
+
+    MAX_ANSWER_TEXT_LENGTH: ClassVar[int] = constants.MAX_ANSWER_CALLBACK_QUERY_TEXT_LENGTH
+    """
+    :const:`telegram.constants.MAX_ANSWER_CALLBACK_QUERY_TEXT_LENGTH`
+
+    .. versionadded:: 13.2
+    """
