@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,34 +21,32 @@
 import logging
 import warnings
 import weakref
-from functools import wraps
-from threading import Thread, Lock, Event, current_thread, BoundedSemaphore
-from time import sleep
-from uuid import uuid4
 from collections import defaultdict
-
-from queue import Queue, Empty
+from functools import wraps
+from queue import Empty, Queue
+from threading import BoundedSemaphore, Event, Lock, Thread, current_thread
+from time import sleep
+from typing import TYPE_CHECKING, Callable, DefaultDict, Dict, List, Optional, Set, Union
+from uuid import uuid4
 
 from telegram import TelegramError, Update
-from telegram.ext.handler import Handler
-from telegram.ext.callbackcontext import CallbackContext
-from telegram.utils.deprecate import TelegramDeprecationWarning
-from telegram.utils.promise import Promise
 from telegram.ext import BasePersistence
-
-from typing import Any, Callable, TYPE_CHECKING, Optional, Union, DefaultDict, Dict, List, Set
-
-from telegram.utils.types import HandlerArg
+from telegram.ext.callbackcontext import CallbackContext
+from telegram.ext.handler import Handler
+from telegram.utils.deprecate import TelegramDeprecationWarning
+from telegram.ext.utils.promise import Promise
+from telegram.utils.helpers import DefaultValue, DEFAULT_FALSE
 
 if TYPE_CHECKING:
     from telegram import Bot
     from telegram.ext import JobQueue
 
-DEFAULT_GROUP = 0
+DEFAULT_GROUP: int = 0
 
 
-def run_async(func: Callable[[Update, CallbackContext],
-                             Any]) -> Callable[[Update, CallbackContext], Any]:
+def run_async(
+    func: Callable[[Update, CallbackContext], object]
+) -> Callable[[Update, CallbackContext], object]:
     """
     Function decorator that will run the function in a new thread.
 
@@ -66,20 +64,23 @@ def run_async(func: Callable[[Update, CallbackContext],
     """
 
     @wraps(func)
-    def async_func(*args: Any, **kwargs: Any) -> Any:
-        warnings.warn('The @run_async decorator is deprecated. Use the `run_async` parameter of'
-                      '`Dispatcher.add_handler` or `Dispatcher.run_async` instead.',
-                      TelegramDeprecationWarning,
-                      stacklevel=2)
-        return Dispatcher.get_instance()._run_async(func, *args, update=None, error_handling=False,
-                                                    **kwargs)
+    def async_func(*args: object, **kwargs: object) -> object:
+        warnings.warn(
+            'The @run_async decorator is deprecated. Use the `run_async` parameter of '
+            'your Handler or `Dispatcher.run_async` instead.',
+            TelegramDeprecationWarning,
+            stacklevel=2,
+        )
+        return Dispatcher.get_instance()._run_async(  # pylint: disable=W0212
+            func, *args, update=None, error_handling=False, **kwargs
+        )
 
     return async_func
 
 
 class DispatcherHandlerStop(Exception):
     """
-    Raise this in handler to prevent execution any other handler (even in different group).
+    Raise this in handler to prevent execution of any other handler (even in different group).
 
     In order to use this exception in a :class:`telegram.ext.ConversationHandler`, pass the
     optional ``state`` parameter instead of returning the next state:
@@ -96,6 +97,7 @@ class DispatcherHandlerStop(Exception):
     Args:
         state (:obj:`object`, optional): The next state of the conversation.
     """
+
     def __init__(self, state: object = None) -> None:
         super().__init__()
         self.state = state
@@ -104,19 +106,6 @@ class DispatcherHandlerStop(Exception):
 class Dispatcher:
     """This class dispatches all kinds of updates to its registered handlers.
 
-    Attributes:
-        bot (:class:`telegram.Bot`): The bot object that should be passed to the handlers.
-        update_queue (:obj:`Queue`): The synchronized queue that will contain the updates.
-        job_queue (:class:`telegram.ext.JobQueue`): Optional. The :class:`telegram.ext.JobQueue`
-            instance to pass onto handler callbacks.
-        workers (:obj:`int`, optional): Number of maximum concurrent worker threads for the
-            ``@run_async`` decorator and :meth:`run_async`.
-        user_data (:obj:`defaultdict`): A dictionary handlers can use to store data for the user.
-        chat_data (:obj:`defaultdict`): A dictionary handlers can use to store data for the chat.
-        bot_data (:obj:`dict`): A dictionary handlers can use to store data for the bot.
-        persistence (:class:`telegram.ext.BasePersistence`): Optional. The persistence class to
-            store data that should be persistent over restarts.
-
     Args:
         bot (:class:`telegram.Bot`): The bot object that should be passed to the handlers.
         update_queue (:obj:`Queue`): The synchronized queue that will contain the updates.
@@ -130,6 +119,19 @@ class Dispatcher:
             API (ignored if `dispatcher` argument is used). Defaults to :obj:`True`.
             **New users**: set this to :obj:`True`.
 
+    Attributes:
+        bot (:class:`telegram.Bot`): The bot object that should be passed to the handlers.
+        update_queue (:obj:`Queue`): The synchronized queue that will contain the updates.
+        job_queue (:class:`telegram.ext.JobQueue`): Optional. The :class:`telegram.ext.JobQueue`
+            instance to pass onto handler callbacks.
+        workers (:obj:`int`, optional): Number of maximum concurrent worker threads for the
+            ``@run_async`` decorator and :meth:`run_async`.
+        user_data (:obj:`defaultdict`): A dictionary handlers can use to store data for the user.
+        chat_data (:obj:`defaultdict`): A dictionary handlers can use to store data for the chat.
+        bot_data (:obj:`dict`): A dictionary handlers can use to store data for the bot.
+        persistence (:class:`telegram.ext.BasePersistence`): Optional. The persistence class to
+            store data that should be persistent over restarts.
+
     """
 
     __singleton_lock = Lock()
@@ -137,14 +139,16 @@ class Dispatcher:
     __singleton = None
     logger = logging.getLogger(__name__)
 
-    def __init__(self,
-                 bot: 'Bot',
-                 update_queue: Queue,
-                 workers: int = 4,
-                 exception_event: Event = None,
-                 job_queue: 'JobQueue' = None,
-                 persistence: BasePersistence = None,
-                 use_context: bool = True):
+    def __init__(
+        self,
+        bot: 'Bot',
+        update_queue: Queue,
+        workers: int = 4,
+        exception_event: Event = None,
+        job_queue: 'JobQueue' = None,
+        persistence: BasePersistence = None,
+        use_context: bool = True,
+    ):
         self.bot = bot
         self.update_queue = update_queue
         self.job_queue = job_queue
@@ -152,11 +156,14 @@ class Dispatcher:
         self.use_context = use_context
 
         if not use_context:
-            warnings.warn('Old Handler API is deprecated - see https://git.io/fxJuV for details',
-                          TelegramDeprecationWarning, stacklevel=3)
+            warnings.warn(
+                'Old Handler API is deprecated - see https://git.io/fxJuV for details',
+                TelegramDeprecationWarning,
+                stacklevel=3,
+            )
 
-        self.user_data: DefaultDict[int, Dict[Any, Any]] = defaultdict(dict)
-        self.chat_data: DefaultDict[int, Dict[Any, Any]] = defaultdict(dict)
+        self.user_data: DefaultDict[int, Dict[object, object]] = defaultdict(dict)
+        self.chat_data: DefaultDict[int, Dict[object, object]] = defaultdict(dict)
         self.bot_data = {}
         self.persistence: Optional[BasePersistence] = None
         self._update_persistence_lock = Lock()
@@ -184,7 +191,7 @@ class Dispatcher:
         """Dict[:obj:`int`, List[:class:`telegram.ext.Handler`]]: Holds the handlers per group."""
         self.groups: List[int] = []
         """List[:obj:`int`]: A list with all groups."""
-        self.error_handlers: Dict[Callable, bool] = {}
+        self.error_handlers: Dict[Callable, Union[bool, DefaultValue]] = {}
         """Dict[:obj:`callable`, :obj:`bool`]: A dict, where the keys are error handlers and the
         values indicate whether they are to be run asynchronously."""
 
@@ -208,11 +215,10 @@ class Dispatcher:
         return self.__exception_event
 
     def _init_async_threads(self, base_name: str, workers: int) -> None:
-        base_name = '{}_'.format(base_name) if base_name else ''
+        base_name = f'{base_name}_' if base_name else ''
 
         for i in range(workers):
-            thread = Thread(target=self._pooled, name='Bot:{}:worker:{}{}'.format(self.bot.id,
-                                                                                  base_name, i))
+            thread = Thread(target=self._pooled, name=f'Bot:{self.bot.id}:worker:{base_name}{i}')
             self.__async_threads.add(thread)
             thread.start()
 
@@ -234,9 +240,7 @@ class Dispatcher:
         """
         if cls.__singleton is not None:
             return cls.__singleton()  # type: ignore[return-value] # pylint: disable=not-callable
-        else:
-            raise RuntimeError('{} not initialized or multiple instances exist'.format(
-                cls.__name__))
+        raise RuntimeError(f'{cls.__name__} not initialized or multiple instances exist')
 
     def _pooled(self) -> None:
         thr_name = current_thread().getName()
@@ -245,8 +249,9 @@ class Dispatcher:
 
             # If unpacking fails, the thread pool is being closed from Updater._join_async_threads
             if not isinstance(promise, Promise):
-                self.logger.debug("Closing run_async thread %s/%d", thr_name,
-                                  len(self.__async_threads))
+                self.logger.debug(
+                    "Closing run_async thread %s/%d", thr_name, len(self.__async_threads)
+                )
                 break
 
             promise.run()
@@ -258,7 +263,8 @@ class Dispatcher:
             if isinstance(promise.exception, DispatcherHandlerStop):
                 self.logger.warning(
                     'DispatcherHandlerStop is not supported with async functions; func: %s',
-                    promise.pooled_function.__name__)
+                    promise.pooled_function.__name__,
+                )
                 continue
 
             # Avoid infinite recursion of error handlers.
@@ -280,11 +286,9 @@ class Dispatcher:
             except Exception:
                 self.logger.exception('An uncaught error was raised while handling the error.')
 
-    def run_async(self,
-                  func: Callable[..., Any],
-                  *args: Any,
-                  update: HandlerArg = None,
-                  **kwargs: Any) -> Promise:
+    def run_async(
+        self, func: Callable[..., object], *args: object, update: object = None, **kwargs: object
+    ) -> Promise:
         """
         Queue a function (with given args/kwargs) to be run asynchronously. Exceptions raised
         by the function will be handled by the error handlers registered with
@@ -299,9 +303,9 @@ class Dispatcher:
         Args:
             func (:obj:`callable`): The function to run in the thread.
             *args (:obj:`tuple`, optional): Arguments to ``func``.
-            update (:class:`telegram.Update`, optional): The update associated with the functions
-                call. If passed, it will be available in the error handlers, in case an exception
-                is raised by :attr:`func`.
+            update (:class:`telegram.Update` | :obj:`object`, optional): The update associated with
+                the functions call. If passed, it will be available in the error handlers, in case
+                an exception is raised by :attr:`func`.
             **kwargs (:obj:`dict`, optional): Keyword arguments to ``func``.
 
         Returns:
@@ -310,12 +314,14 @@ class Dispatcher:
         """
         return self._run_async(func, *args, update=update, error_handling=True, **kwargs)
 
-    def _run_async(self,
-                   func: Callable[..., Any],
-                   *args: Any,
-                   update: HandlerArg = None,
-                   error_handling: bool = True,
-                   **kwargs: Any) -> Promise:
+    def _run_async(
+        self,
+        func: Callable[..., object],
+        *args: object,
+        update: object = None,
+        error_handling: bool = True,
+        **kwargs: object,
+    ) -> Promise:
         # TODO: Remove error_handling parameter once we drop the @run_async decorator
         promise = Promise(func, args, kwargs, update=update, error_handling=error_handling)
         self.__async_queue.put(promise)
@@ -357,12 +363,12 @@ class Dispatcher:
                 if self.__stop_event.is_set():
                     self.logger.debug('orderly stopping')
                     break
-                elif self.__exception_event.is_set():
+                if self.__exception_event.is_set():
                     self.logger.critical('stopping due to exception in another thread')
                     break
                 continue
 
-            self.logger.debug('Processing Update: %s' % update)
+            self.logger.debug('Processing Update: %s', update)
             self.process_update(update)
             self.update_queue.task_done()
 
@@ -387,20 +393,27 @@ class Dispatcher:
             self.__async_queue.put(None)
 
         for i, thr in enumerate(threads):
-            self.logger.debug('Waiting for async thread {}/{} to end'.format(i + 1, total))
+            self.logger.debug('Waiting for async thread %s/%s to end', i + 1, total)
             thr.join()
             self.__async_threads.remove(thr)
-            self.logger.debug('async thread {}/{} has ended'.format(i + 1, total))
+            self.logger.debug('async thread %s/%s has ended', i + 1, total)
 
     @property
     def has_running_threads(self) -> bool:
         return self.running or bool(self.__async_threads)
 
-    def process_update(self, update: Union[str, Update, TelegramError]) -> None:
-        """Processes a single update.
+    def process_update(self, update: object) -> None:
+        """Processes a single update and updates the persistence.
+
+        Note:
+            If the update is handled by least one synchronously running handlers (i.e.
+            ``run_async=False``), :meth:`update_persistence` is called *once* after all handlers
+            synchronous handlers are done. Each asynchronously running handler will trigger
+            :meth:`update_persistence` on its own.
 
         Args:
-            update (:obj:`str` | :class:`telegram.Update` | :class:`telegram.TelegramError`):
+            update (:class:`telegram.Update` | :obj:`object` | \
+                :class:`telegram.error.TelegramError`):
                 The update to process.
 
         """
@@ -414,6 +427,8 @@ class Dispatcher:
             return
 
         context = None
+        handled = False
+        sync_modes = []
 
         for group in self.groups:
             try:
@@ -422,11 +437,9 @@ class Dispatcher:
                     if check is not None and check is not False:
                         if not context and self.use_context:
                             context = CallbackContext.from_update(update, self)
+                        handled = True
+                        sync_modes.append(handler.run_async)
                         handler.handle_update(update, self, check, context)
-
-                        # If handler runs async updating immediately doesn't make sense
-                        if not handler.run_async:
-                            self.update_persistence(update=update)
                         break
 
             # Stop processing with any other handler.
@@ -436,9 +449,9 @@ class Dispatcher:
                 break
 
             # Dispatch any error.
-            except Exception as e:
+            except Exception as exc:
                 try:
-                    self.dispatch_error(update, e)
+                    self.dispatch_error(update, exc)
                 except DispatcherHandlerStop:
                     self.logger.debug('Error handler stopped further handlers')
                     break
@@ -446,6 +459,16 @@ class Dispatcher:
                 except Exception:
                     self.logger.exception('An uncaught error was raised while handling the error.')
 
+        # Update persistence, if handled
+        handled_only_async = all(sync_modes)
+        if handled:
+            # Respect default settings
+            if all(mode is DEFAULT_FALSE for mode in sync_modes) and self.bot.defaults:
+                handled_only_async = self.bot.defaults.run_async
+            # If update was only handled by async handlers, we don't need to update here
+            if not handled_only_async:
+                self.update_persistence(update=update)
+
     def add_handler(self, handler: Handler, group: int = DEFAULT_GROUP) -> None:
         """Register a handler.
 
@@ -472,17 +495,18 @@ class Dispatcher:
 
         """
         # Unfortunately due to circular imports this has to be here
-        from .conversationhandler import ConversationHandler
+        from .conversationhandler import ConversationHandler  # pylint: disable=C0415
 
         if not isinstance(handler, Handler):
-            raise TypeError('handler is not an instance of {}'.format(Handler.__name__))
+            raise TypeError(f'handler is not an instance of {Handler.__name__}')
         if not isinstance(group, int):
             raise TypeError('group is not int')
         if isinstance(handler, ConversationHandler) and handler.persistent and handler.name:
             if not self.persistence:
                 raise ValueError(
-                    "ConversationHandler {} can not be persistent if dispatcher has no "
-                    "persistence".format(handler.name))
+                    f"ConversationHandler {handler.name} can not be persistent if dispatcher has "
+                    f"no persistence"
+                )
             handler.persistence = self.persistence
             handler.conversations = self.persistence.get_conversations(handler.name)
 
@@ -507,7 +531,7 @@ class Dispatcher:
                 del self.handlers[group]
                 self.groups.remove(group)
 
-    def update_persistence(self, update: HandlerArg = None) -> None:
+    def update_persistence(self, update: object = None) -> None:
         """Update :attr:`user_data`, :attr:`chat_data` and :attr:`bot_data` in :attr:`persistence`.
 
         Args:
@@ -517,7 +541,7 @@ class Dispatcher:
         with self._update_persistence_lock:
             self.__update_persistence(update)
 
-    def __update_persistence(self, update: HandlerArg = None) -> None:
+    def __update_persistence(self, update: object = None) -> None:
         if self.persistence:
             # We use list() here in order to decouple chat_ids from self.chat_data, as dict view
             # objects will change, when the dict does and we want to loop over chat_ids
@@ -537,42 +561,50 @@ class Dispatcher:
             if self.persistence.store_bot_data:
                 try:
                     self.persistence.update_bot_data(self.bot_data)
-                except Exception as e:
+                except Exception as exc:
                     try:
-                        self.dispatch_error(update, e)
+                        self.dispatch_error(update, exc)
                     except Exception:
-                        message = 'Saving bot data raised an error and an ' \
-                                  'uncaught error was raised while handling ' \
-                                  'the error with an error_handler'
+                        message = (
+                            'Saving bot data raised an error and an '
+                            'uncaught error was raised while handling '
+                            'the error with an error_handler'
+                        )
                         self.logger.exception(message)
             if self.persistence.store_chat_data:
                 for chat_id in chat_ids:
                     try:
                         self.persistence.update_chat_data(chat_id, self.chat_data[chat_id])
-                    except Exception as e:
+                    except Exception as exc:
                         try:
-                            self.dispatch_error(update, e)
+                            self.dispatch_error(update, exc)
                         except Exception:
-                            message = 'Saving chat data raised an error and an ' \
-                                      'uncaught error was raised while handling ' \
-                                      'the error with an error_handler'
+                            message = (
+                                'Saving chat data raised an error and an '
+                                'uncaught error was raised while handling '
+                                'the error with an error_handler'
+                            )
                             self.logger.exception(message)
             if self.persistence.store_user_data:
                 for user_id in user_ids:
                     try:
                         self.persistence.update_user_data(user_id, self.user_data[user_id])
-                    except Exception as e:
+                    except Exception as exc:
                         try:
-                            self.dispatch_error(update, e)
+                            self.dispatch_error(update, exc)
                         except Exception:
-                            message = 'Saving user data raised an error and an ' \
-                                      'uncaught error was raised while handling ' \
-                                      'the error with an error_handler'
+                            message = (
+                                'Saving user data raised an error and an '
+                                'uncaught error was raised while handling '
+                                'the error with an error_handler'
+                            )
                             self.logger.exception(message)
 
-    def add_error_handler(self,
-                          callback: Callable[[Any, CallbackContext], None],
-                          run_async: bool = False) -> None:
+    def add_error_handler(
+        self,
+        callback: Callable[[object, CallbackContext], None],
+        run_async: Union[bool, DefaultValue] = DEFAULT_FALSE,  # pylint: disable=W0621
+    ) -> None:
         """Registers an error handler in the Dispatcher. This handler will receive every error
         which happens in your bot.
 
@@ -587,7 +619,7 @@ class Dispatcher:
             callback (:obj:`callable`): The callback function for this error handler. Will be
                 called when an error is raised. Callback signature for context based API:
 
-                ``def callback(update: Update, context: CallbackContext)``
+                ``def callback(update: object, context: CallbackContext)``
 
                 The error that happened will be present in context.error.
             run_async (:obj:`bool`, optional): Whether this handlers callback should be run
@@ -599,9 +631,14 @@ class Dispatcher:
         if callback in self.error_handlers:
             self.logger.debug('The callback is already registered as an error handler. Ignoring.')
             return
+
+        if run_async is DEFAULT_FALSE and self.bot.defaults:
+            if self.bot.defaults.run_async:
+                run_async = True
+
         self.error_handlers[callback] = run_async
 
-    def remove_error_handler(self, callback: Callable[[Any, CallbackContext], None]) -> None:
+    def remove_error_handler(self, callback: Callable[[object, CallbackContext], None]) -> None:
         """Removes an error handler.
 
         Args:
@@ -610,14 +647,13 @@ class Dispatcher:
         """
         self.error_handlers.pop(callback, None)
 
-    def dispatch_error(self,
-                       update: Optional[HandlerArg],
-                       error: Exception,
-                       promise: Promise = None) -> None:
+    def dispatch_error(
+        self, update: Optional[object], error: Exception, promise: Promise = None
+    ) -> None:
         """Dispatches an error.
 
         Args:
-            update (:obj:`str` | :class:`telegram.Update` | None): The update that caused the error
+            update (:obj:`object` | :class:`telegram.Update`): The update that caused the error.
             error (:obj:`Exception`): The error that was raised.
             promise (:class:`telegram.utils.Promise`, optional): The promise whose pooled function
                 raised the error.
@@ -627,11 +663,11 @@ class Dispatcher:
         async_kwargs = None if not promise else promise.kwargs
 
         if self.error_handlers:
-            for callback, run_async in self.error_handlers.items():
+            for callback, run_async in self.error_handlers.items():  # pylint: disable=W0621
                 if self.use_context:
-                    context = CallbackContext.from_error(update, error, self,
-                                                         async_args=async_args,
-                                                         async_kwargs=async_kwargs)
+                    context = CallbackContext.from_error(
+                        update, error, self, async_args=async_args, async_kwargs=async_kwargs
+                    )
                     if run_async:
                         self.run_async(callback, update, context, update=update)
                     else:
@@ -644,4 +680,5 @@ class Dispatcher:
 
         else:
             self.logger.exception(
-                'No error handlers are registered, logging exception.', exc_info=error)
+                'No error handlers are registered, logging exception.', exc_info=error
+            )
