@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,32 +19,22 @@
 """This module contains the base class for handlers as used by the Dispatcher."""
 
 from abc import ABC, abstractmethod
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, TypeVar, Union, Generic
 
-from telegram.utils.promise import Promise
-from telegram.utils.types import HandlerArg
 from telegram import Update
-from typing import Callable, TYPE_CHECKING, Any, Optional, Union, TypeVar, Dict
+from telegram.ext.utils.promise import Promise
+from telegram.utils.helpers import DefaultValue, DEFAULT_FALSE
+
 if TYPE_CHECKING:
     from telegram.ext import CallbackContext, Dispatcher
 
 RT = TypeVar('RT')
+UT = TypeVar('UT')
 
 
-class Handler(ABC):
+class Handler(Generic[UT], ABC):
     """The base class for all update handlers. Create custom handlers by inheriting from it.
 
-    Attributes:
-        callback (:obj:`callable`): The callback function for this handler.
-        pass_update_queue (:obj:`bool`): Determines whether ``update_queue`` will be
-            passed to the callback function.
-        pass_job_queue (:obj:`bool`): Determines whether ``job_queue`` will be passed to
-            the callback function.
-        pass_user_data (:obj:`bool`): Determines whether ``user_data`` will be passed to
-            the callback function.
-        pass_chat_data (:obj:`bool`): Determines whether ``chat_data`` will be passed to
-            the callback function.
-        run_async (:obj:`bool`): Determines whether the callback will run asynchronously.
-
     Note:
         :attr:`pass_user_data` and :attr:`pass_chat_data` determine whether a ``dict`` you
         can use to keep any data in will be sent to the :attr:`callback` function. Related to
@@ -86,15 +76,30 @@ class Handler(ABC):
         run_async (:obj:`bool`): Determines whether the callback will run asynchronously.
             Defaults to :obj:`False`.
 
+    Attributes:
+        callback (:obj:`callable`): The callback function for this handler.
+        pass_update_queue (:obj:`bool`): Determines whether ``update_queue`` will be
+            passed to the callback function.
+        pass_job_queue (:obj:`bool`): Determines whether ``job_queue`` will be passed to
+            the callback function.
+        pass_user_data (:obj:`bool`): Determines whether ``user_data`` will be passed to
+            the callback function.
+        pass_chat_data (:obj:`bool`): Determines whether ``chat_data`` will be passed to
+            the callback function.
+        run_async (:obj:`bool`): Determines whether the callback will run asynchronously.
+
     """
-    def __init__(self,
-                 callback: Callable[[HandlerArg, 'CallbackContext'], RT],
-                 pass_update_queue: bool = False,
-                 pass_job_queue: bool = False,
-                 pass_user_data: bool = False,
-                 pass_chat_data: bool = False,
-                 run_async: bool = False):
-        self.callback: Callable[[HandlerArg, 'CallbackContext'], RT] = callback
+
+    def __init__(
+        self,
+        callback: Callable[[UT, 'CallbackContext'], RT],
+        pass_update_queue: bool = False,
+        pass_job_queue: bool = False,
+        pass_user_data: bool = False,
+        pass_chat_data: bool = False,
+        run_async: Union[bool, DefaultValue] = DEFAULT_FALSE,
+    ):
+        self.callback = callback
         self.pass_update_queue = pass_update_queue
         self.pass_job_queue = pass_job_queue
         self.pass_user_data = pass_user_data
@@ -102,11 +107,15 @@ class Handler(ABC):
         self.run_async = run_async
 
     @abstractmethod
-    def check_update(self, update: HandlerArg) -> Optional[Union[bool, object]]:
+    def check_update(self, update: object) -> Optional[Union[bool, object]]:
         """
         This method is called to determine if an update should be handled by
         this handler instance. It should always be overridden.
 
+        Note:
+            Custom updates types can be handled by the dispatcher. Therefore, an implementation of
+            this method should always check the type of :attr:`update`.
+
         Args:
             update (:obj:`str` | :class:`telegram.Update`): The update to be tested.
 
@@ -117,11 +126,13 @@ class Handler(ABC):
 
         """
 
-    def handle_update(self,
-                      update: HandlerArg,
-                      dispatcher: 'Dispatcher',
-                      check_result: object,
-                      context: 'CallbackContext' = None) -> Union[RT, Promise]:
+    def handle_update(
+        self,
+        update: UT,
+        dispatcher: 'Dispatcher',
+        check_result: object,
+        context: 'CallbackContext' = None,
+    ) -> Union[RT, Promise]:
         """
         This method is called if it was determined that an update should indeed
         be handled by this instance. Calls :attr:`callback` along with its respectful
@@ -137,25 +148,31 @@ class Handler(ABC):
                 the dispatcher.
 
         """
+        run_async = self.run_async
+        if self.run_async is DEFAULT_FALSE and dispatcher.bot.defaults:
+            if dispatcher.bot.defaults.run_async:
+                run_async = True
+
         if context:
             self.collect_additional_context(context, update, dispatcher, check_result)
-            if self.run_async:
+            if run_async:
                 return dispatcher.run_async(self.callback, update, context, update=update)
-            else:
-                return self.callback(update, context)
-        else:
-            optional_args = self.collect_optional_args(dispatcher, update, check_result)
-            if self.run_async:
-                return dispatcher.run_async(self.callback, dispatcher.bot, update, update=update,
-                                            **optional_args)
-            else:
-                return self.callback(dispatcher.bot, update, **optional_args)  # type: ignore
+            return self.callback(update, context)
 
-    def collect_additional_context(self,
-                                   context: 'CallbackContext',
-                                   update: HandlerArg,
-                                   dispatcher: 'Dispatcher',
-                                   check_result: Any) -> None:
+        optional_args = self.collect_optional_args(dispatcher, update, check_result)
+        if run_async:
+            return dispatcher.run_async(
+                self.callback, dispatcher.bot, update, update=update, **optional_args
+            )
+        return self.callback(dispatcher.bot, update, **optional_args)  # type: ignore
+
+    def collect_additional_context(
+        self,
+        context: 'CallbackContext',
+        update: UT,
+        dispatcher: 'Dispatcher',
+        check_result: Any,
+    ) -> None:
         """Prepares additional arguments for the context. Override if needed.
 
         Args:
@@ -165,12 +182,13 @@ class Handler(ABC):
             check_result: The result (return value) from :attr:`check_update`.
 
         """
-        pass
 
-    def collect_optional_args(self,
-                              dispatcher: 'Dispatcher',
-                              update: HandlerArg = None,
-                              check_result: Any = None) -> Dict[str, Any]:
+    def collect_optional_args(
+        self,
+        dispatcher: 'Dispatcher',
+        update: UT = None,
+        check_result: Any = None,  # pylint: disable=W0613
+    ) -> Dict[str, object]:
         """
         Prepares the optional arguments. If the handler has additional optional args,
         it should subclass this method, but remember to call this super method.
@@ -184,7 +202,7 @@ class Handler(ABC):
             check_result: The result from check_update
 
         """
-        optional_args: Dict[str, Any] = dict()
+        optional_args: Dict[str, object] = dict()
 
         if self.pass_update_queue:
             optional_args['update_queue'] = dispatcher.update_queue
@@ -193,10 +211,12 @@ class Handler(ABC):
         if self.pass_user_data and isinstance(update, Update):
             user = update.effective_user
             optional_args['user_data'] = dispatcher.user_data[
-                user.id if user else None]  # type: ignore[index]
+                user.id if user else None  # type: ignore[index]
+            ]
         if self.pass_chat_data and isinstance(update, Update):
             chat = update.effective_chat
             optional_args['chat_data'] = dispatcher.chat_data[
-                chat.id if chat else None]  # type: ignore[index]
+                chat.id if chat else None  # type: ignore[index]
+            ]
 
         return optional_args
