@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -20,10 +20,9 @@
 import pickle
 from collections import defaultdict
 from copy import deepcopy
+from typing import Any, DefaultDict, Dict, Optional, Tuple
 
 from telegram.ext import BasePersistence
-
-from typing import DefaultDict, Dict, Any, Tuple, Optional
 from telegram.utils.types import ConversationDict
 
 
@@ -39,23 +38,6 @@ class PicklePersistence(BasePersistence):
         :meth:`telegram.ext.BasePersistence.replace_bot` and
         :meth:`telegram.ext.BasePersistence.insert_bot`.
 
-    Attributes:
-        filename (:obj:`str`): The filename for storing the pickle files. When :attr:`single_file`
-            is :obj:`False` this will be used as a prefix.
-        store_user_data (:obj:`bool`): Optional. Whether user_data should be saved by this
-            persistence class.
-        store_chat_data (:obj:`bool`): Optional. Whether user_data should be saved by this
-            persistence class.
-        store_bot_data (:obj:`bool`): Optional. Whether bot_data should be saved by this
-            persistence class.
-        single_file (:obj:`bool`): Optional. When :obj:`False` will store 3 separate files of
-            `filename_user_data`, `filename_chat_data` and `filename_conversations`. Default is
-            :obj:`True`.
-        on_flush (:obj:`bool`, optional): When :obj:`True` will only save to file when
-            :meth:`flush` is called and keep data in memory until that happens. When
-            :obj:`False` will store data on any transaction *and* on call to :meth:`flush`.
-            Default is :obj:`False`.
-
     Args:
         filename (:obj:`str`): The filename for storing the pickle files. When :attr:`single_file`
             is :obj:`False` this will be used as a prefix.
@@ -72,68 +54,95 @@ class PicklePersistence(BasePersistence):
             :meth:`flush` is called and keep data in memory until that happens. When
             :obj:`False` will store data on any transaction *and* on call to :meth:`flush`.
             Default is :obj:`False`.
+
+    Attributes:
+        filename (:obj:`str`): The filename for storing the pickle files. When :attr:`single_file`
+            is :obj:`False` this will be used as a prefix.
+        store_user_data (:obj:`bool`): Optional. Whether user_data should be saved by this
+            persistence class.
+        store_chat_data (:obj:`bool`): Optional. Whether user_data should be saved by this
+            persistence class.
+        store_bot_data (:obj:`bool`): Optional. Whether bot_data should be saved by this
+            persistence class.
+        single_file (:obj:`bool`): Optional. When :obj:`False` will store 3 separate files of
+            `filename_user_data`, `filename_chat_data` and `filename_conversations`. Default is
+            :obj:`True`.
+        on_flush (:obj:`bool`, optional): When :obj:`True` will only save to file when
+            :meth:`flush` is called and keep data in memory until that happens. When
+            :obj:`False` will store data on any transaction *and* on call to :meth:`flush`.
+            Default is :obj:`False`.
     """
 
-    def __init__(self,
-                 filename: str,
-                 store_user_data: bool = True,
-                 store_chat_data: bool = True,
-                 store_bot_data: bool = True,
-                 single_file: bool = True,
-                 on_flush: bool = False):
-        super().__init__(store_user_data=store_user_data,
-                         store_chat_data=store_chat_data,
-                         store_bot_data=store_bot_data)
+    def __init__(
+        self,
+        filename: str,
+        store_user_data: bool = True,
+        store_chat_data: bool = True,
+        store_bot_data: bool = True,
+        single_file: bool = True,
+        on_flush: bool = False,
+    ):
+        super().__init__(
+            store_user_data=store_user_data,
+            store_chat_data=store_chat_data,
+            store_bot_data=store_bot_data,
+        )
         self.filename = filename
         self.single_file = single_file
         self.on_flush = on_flush
         self.user_data: Optional[DefaultDict[int, Dict]] = None
         self.chat_data: Optional[DefaultDict[int, Dict]] = None
         self.bot_data: Optional[Dict] = None
-        self.conversations: Optional[Dict[str, Dict[Tuple, Any]]] = None
+        self.conversations: Optional[Dict[str, Dict[Tuple, object]]] = None
 
     def load_singlefile(self) -> None:
         try:
             filename = self.filename
-            with open(self.filename, "rb") as f:
-                data = pickle.load(f)
+            with open(self.filename, "rb") as file:
+                data = pickle.load(file)
                 self.user_data = defaultdict(dict, data['user_data'])
                 self.chat_data = defaultdict(dict, data['chat_data'])
                 # For backwards compatibility with files not containing bot data
                 self.bot_data = data.get('bot_data', {})
                 self.conversations = data['conversations']
-        except IOError:
+        except OSError:
             self.conversations = dict()
             self.user_data = defaultdict(dict)
             self.chat_data = defaultdict(dict)
             self.bot_data = {}
-        except pickle.UnpicklingError:
-            raise TypeError("File {} does not contain valid pickle data".format(filename))
-        except Exception:
-            raise TypeError("Something went wrong unpickling {}".format(filename))
+        except pickle.UnpicklingError as exc:
+            raise TypeError(f"File {filename} does not contain valid pickle data") from exc
+        except Exception as exc:
+            raise TypeError(f"Something went wrong unpickling {filename}") from exc
 
-    def load_file(self, filename: str) -> Any:
+    @staticmethod
+    def load_file(filename: str) -> Any:
         try:
-            with open(filename, "rb") as f:
-                return pickle.load(f)
-        except IOError:
+            with open(filename, "rb") as file:
+                return pickle.load(file)
+        except OSError:
             return None
-        except pickle.UnpicklingError:
-            raise TypeError("File {} does not contain valid pickle data".format(filename))
-        except Exception:
-            raise TypeError("Something went wrong unpickling {}".format(filename))
+        except pickle.UnpicklingError as exc:
+            raise TypeError(f"File {filename} does not contain valid pickle data") from exc
+        except Exception as exc:
+            raise TypeError(f"Something went wrong unpickling {filename}") from exc
 
     def dump_singlefile(self) -> None:
-        with open(self.filename, "wb") as f:
-            data = {'conversations': self.conversations, 'user_data': self.user_data,
-                    'chat_data': self.chat_data, 'bot_data': self.bot_data}
-            pickle.dump(data, f)
+        with open(self.filename, "wb") as file:
+            data = {
+                'conversations': self.conversations,
+                'user_data': self.user_data,
+                'chat_data': self.chat_data,
+                'bot_data': self.bot_data,
+            }
+            pickle.dump(data, file)
 
-    def dump_file(self, filename: str, data: Any) -> None:
-        with open(filename, "wb") as f:
-            pickle.dump(data, f)
+    @staticmethod
+    def dump_file(filename: str, data: object) -> None:
+        with open(filename, "wb") as file:
+            pickle.dump(data, file)
 
-    def get_user_data(self) -> DefaultDict[int, Dict[Any, Any]]:
+    def get_user_data(self) -> DefaultDict[int, Dict[object, object]]:
         """Returns the user_data from the pickle file if it exists or an empty :obj:`defaultdict`.
 
         Returns:
@@ -142,7 +151,7 @@ class PicklePersistence(BasePersistence):
         if self.user_data:
             pass
         elif not self.single_file:
-            filename = "{}_user_data".format(self.filename)
+            filename = f"{self.filename}_user_data"
             data = self.load_file(filename)
             if not data:
                 data = defaultdict(dict)
@@ -153,7 +162,7 @@ class PicklePersistence(BasePersistence):
             self.load_singlefile()
         return deepcopy(self.user_data)  # type: ignore[arg-type]
 
-    def get_chat_data(self) -> DefaultDict[int, Dict[Any, Any]]:
+    def get_chat_data(self) -> DefaultDict[int, Dict[object, object]]:
         """Returns the chat_data from the pickle file if it exists or an empty :obj:`defaultdict`.
 
         Returns:
@@ -162,7 +171,7 @@ class PicklePersistence(BasePersistence):
         if self.chat_data:
             pass
         elif not self.single_file:
-            filename = "{}_chat_data".format(self.filename)
+            filename = f"{self.filename}_chat_data"
             data = self.load_file(filename)
             if not data:
                 data = defaultdict(dict)
@@ -173,7 +182,7 @@ class PicklePersistence(BasePersistence):
             self.load_singlefile()
         return deepcopy(self.chat_data)  # type: ignore[arg-type]
 
-    def get_bot_data(self) -> Dict[Any, Any]:
+    def get_bot_data(self) -> Dict[object, object]:
         """Returns the bot_data from the pickle file if it exists or an empty :obj:`dict`.
 
         Returns:
@@ -182,7 +191,7 @@ class PicklePersistence(BasePersistence):
         if self.bot_data:
             pass
         elif not self.single_file:
-            filename = "{}_bot_data".format(self.filename)
+            filename = f"{self.filename}_bot_data"
             data = self.load_file(filename)
             if not data:
                 data = {}
@@ -203,7 +212,7 @@ class PicklePersistence(BasePersistence):
         if self.conversations:
             pass
         elif not self.single_file:
-            filename = "{}_conversations".format(self.filename)
+            filename = f"{self.filename}_conversations"
             data = self.load_file(filename)
             if not data:
                 data = {name: {}}
@@ -212,9 +221,9 @@ class PicklePersistence(BasePersistence):
             self.load_singlefile()
         return self.conversations.get(name, {}).copy()  # type: ignore[union-attr]
 
-    def update_conversation(self,
-                            name: str, key: Tuple[int, ...],
-                            new_state: Optional[object]) -> None:
+    def update_conversation(
+        self, name: str, key: Tuple[int, ...], new_state: Optional[object]
+    ) -> None:
         """Will update the conversations for the given handler and depending on :attr:`on_flush`
         save the pickle file.
 
@@ -230,7 +239,7 @@ class PicklePersistence(BasePersistence):
         self.conversations[name][key] = new_state
         if not self.on_flush:
             if not self.single_file:
-                filename = "{}_conversations".format(self.filename)
+                filename = f"{self.filename}_conversations"
                 self.dump_file(filename, self.conversations)
             else:
                 self.dump_singlefile()
@@ -249,7 +258,7 @@ class PicklePersistence(BasePersistence):
         self.user_data[user_id] = data
         if not self.on_flush:
             if not self.single_file:
-                filename = "{}_user_data".format(self.filename)
+                filename = f"{self.filename}_user_data"
                 self.dump_file(filename, self.user_data)
             else:
                 self.dump_singlefile()
@@ -268,7 +277,7 @@ class PicklePersistence(BasePersistence):
         self.chat_data[chat_id] = data
         if not self.on_flush:
             if not self.single_file:
-                filename = "{}_chat_data".format(self.filename)
+                filename = f"{self.filename}_chat_data"
                 self.dump_file(filename, self.chat_data)
             else:
                 self.dump_singlefile()
@@ -284,23 +293,22 @@ class PicklePersistence(BasePersistence):
         self.bot_data = data.copy()
         if not self.on_flush:
             if not self.single_file:
-                filename = "{}_bot_data".format(self.filename)
+                filename = f"{self.filename}_bot_data"
                 self.dump_file(filename, self.bot_data)
             else:
                 self.dump_singlefile()
 
     def flush(self) -> None:
-        """ Will save all data in memory to pickle file(s).
-        """
+        """Will save all data in memory to pickle file(s)."""
         if self.single_file:
             if self.user_data or self.chat_data or self.bot_data or self.conversations:
                 self.dump_singlefile()
         else:
             if self.user_data:
-                self.dump_file("{}_user_data".format(self.filename), self.user_data)
+                self.dump_file(f"{self.filename}_user_data", self.user_data)
             if self.chat_data:
-                self.dump_file("{}_chat_data".format(self.filename), self.chat_data)
+                self.dump_file(f"{self.filename}_chat_data", self.chat_data)
             if self.bot_data:
-                self.dump_file("{}_bot_data".format(self.filename), self.bot_data)
+                self.dump_file(f"{self.filename}_bot_data", self.bot_data)
             if self.conversations:
-                self.dump_file("{}_conversations".format(self.filename), self.conversations)
+                self.dump_file(f"{self.filename}_conversations", self.conversations)
