@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,20 +21,19 @@
 import logging
 import ssl
 import warnings
-from threading import Thread, Lock, current_thread, Event
-from time import sleep
-from signal import signal, SIGINT, SIGTERM, SIGABRT
 from queue import Queue
+from signal import SIGABRT, SIGINT, SIGTERM, signal
+from threading import Event, Lock, Thread, current_thread
+from time import sleep
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Union, no_type_check
 
 from telegram import Bot, TelegramError
+from telegram.error import InvalidToken, RetryAfter, TimedOut, Unauthorized
 from telegram.ext import Dispatcher, JobQueue
-from telegram.error import Unauthorized, InvalidToken, RetryAfter, TimedOut
 from telegram.utils.deprecate import TelegramDeprecationWarning
 from telegram.utils.helpers import get_signal_name
 from telegram.utils.request import Request
-from telegram.utils.webhookhandler import (WebhookServer, WebhookAppClass)
-
-from typing import Callable, Dict, TYPE_CHECKING, Any, List, Union, Tuple, no_type_check, Optional
+from telegram.ext.utils.webhookhandler import WebhookAppClass, WebhookServer
 
 if TYPE_CHECKING:
     from telegram.ext import BasePersistence, Defaults
@@ -51,19 +50,10 @@ class Updater:
     production, use a webhook to receive updates. This is achieved using the WebhookServer and
     WebhookHandler classes.
 
-
-    Attributes:
-        bot (:class:`telegram.Bot`): The bot used with this Updater.
-        user_sig_handler (:obj:`function`): Optional. Function to be called when a signal is
-            received.
-        update_queue (:obj:`Queue`): Queue for the updates.
-        job_queue (:class:`telegram.ext.JobQueue`): Jobqueue for the updater.
-        dispatcher (:class:`telegram.ext.Dispatcher`): Dispatcher that handles the updates and
-            dispatches them to the handlers.
-        running (:obj:`bool`): Indicates if the updater is running.
-        persistence (:class:`telegram.ext.BasePersistence`): Optional. The persistence class to
-            store data that should be persistent over restarts.
-        use_context (:obj:`bool`): Optional. :obj:`True` if using context based callbacks.
+    Note:
+        * You must supply either a :attr:`bot` or a :attr:`token` argument.
+        * If you supply a :attr:`bot`, you will need to pass :attr:`defaults` to *both* the bot and
+          the :class:`telegram.ext.Updater`.
 
     Args:
         token (:obj:`str`, optional): The bot's token given by the @BotFather.
@@ -96,38 +86,51 @@ class Updater:
         defaults (:class:`telegram.ext.Defaults`, optional): An object containing default values to
             be used if not set explicitly in the bot methods.
 
-    Note:
-        * You must supply either a :attr:`bot` or a :attr:`token` argument.
-        * If you supply a :attr:`bot`, you will need to pass :attr:`defaults` to *both* the bot and
-          the :class:`telegram.ext.Updater`.
-
     Raises:
         ValueError: If both :attr:`token` and :attr:`bot` are passed or none of them.
 
+
+    Attributes:
+        bot (:class:`telegram.Bot`): The bot used with this Updater.
+        user_sig_handler (:obj:`function`): Optional. Function to be called when a signal is
+            received.
+        update_queue (:obj:`Queue`): Queue for the updates.
+        job_queue (:class:`telegram.ext.JobQueue`): Jobqueue for the updater.
+        dispatcher (:class:`telegram.ext.Dispatcher`): Dispatcher that handles the updates and
+            dispatches them to the handlers.
+        running (:obj:`bool`): Indicates if the updater is running.
+        persistence (:class:`telegram.ext.BasePersistence`): Optional. The persistence class to
+            store data that should be persistent over restarts.
+        use_context (:obj:`bool`): Optional. :obj:`True` if using context based callbacks.
+
     """
 
     _request = None
 
-    def __init__(self,
-                 token: str = None,
-                 base_url: str = None,
-                 workers: int = 4,
-                 bot: Bot = None,
-                 private_key: bytes = None,
-                 private_key_password: bytes = None,
-                 user_sig_handler: Callable = None,
-                 request_kwargs: Dict[str, Any] = None,
-                 persistence: 'BasePersistence' = None,
-                 defaults: 'Defaults' = None,
-                 use_context: bool = True,
-                 dispatcher: Dispatcher = None,
-                 base_file_url: str = None):
+    def __init__(
+        self,
+        token: str = None,
+        base_url: str = None,
+        workers: int = 4,
+        bot: Bot = None,
+        private_key: bytes = None,
+        private_key_password: bytes = None,
+        user_sig_handler: Callable = None,
+        request_kwargs: Dict[str, Any] = None,
+        persistence: 'BasePersistence' = None,
+        defaults: 'Defaults' = None,
+        use_context: bool = True,
+        dispatcher: Dispatcher = None,
+        base_file_url: str = None,
+    ):
 
         if defaults and bot:
-            warnings.warn('Passing defaults to an Updater has no effect when a Bot is passed '
-                          'as well. Pass them to the Bot instead.',
-                          TelegramDeprecationWarning,
-                          stacklevel=2)
+            warnings.warn(
+                'Passing defaults to an Updater has no effect when a Bot is passed '
+                'as well. Pass them to the Bot instead.',
+                TelegramDeprecationWarning,
+                stacklevel=2,
+            )
 
         if dispatcher is None:
             if (token is None) and (bot is None):
@@ -156,7 +159,8 @@ class Updater:
                 if bot.request.con_pool_size < con_pool_size:
                     self.logger.warning(
                         'Connection pool of Request object is smaller than optimal value (%s)',
-                        con_pool_size)
+                        con_pool_size,
+                    )
             else:
                 # we need a connection pool the size of:
                 # * for each of the workers
@@ -169,24 +173,28 @@ class Updater:
                 if 'con_pool_size' not in request_kwargs:
                     request_kwargs['con_pool_size'] = con_pool_size
                 self._request = Request(**request_kwargs)
-                self.bot = Bot(token,  # type: ignore[arg-type]
-                               base_url,
-                               base_file_url=base_file_url,
-                               request=self._request,
-                               private_key=private_key,
-                               private_key_password=private_key_password,
-                               defaults=defaults)
+                self.bot = Bot(
+                    token,  # type: ignore[arg-type]
+                    base_url,
+                    base_file_url=base_file_url,
+                    request=self._request,
+                    private_key=private_key,
+                    private_key_password=private_key_password,
+                    defaults=defaults,
+                )
             self.update_queue: Queue = Queue()
             self.job_queue = JobQueue()
             self.__exception_event = Event()
             self.persistence = persistence
-            self.dispatcher = Dispatcher(self.bot,
-                                         self.update_queue,
-                                         job_queue=self.job_queue,
-                                         workers=workers,
-                                         exception_event=self.__exception_event,
-                                         persistence=persistence,
-                                         use_context=use_context)
+            self.dispatcher = Dispatcher(
+                self.bot,
+                self.update_queue,
+                job_queue=self.job_queue,
+                workers=workers,
+                exception_event=self.__exception_event,
+                persistence=persistence,
+                use_context=use_context,
+            )
             self.job_queue.set_dispatcher(self.dispatcher)
         else:
             con_pool_size = dispatcher.workers + 4
@@ -195,7 +203,8 @@ class Updater:
             if self.bot.request.con_pool_size < con_pool_size:
                 self.logger.warning(
                     'Connection pool of Request object is smaller than optimal value (%s)',
-                    con_pool_size)
+                    con_pool_size,
+                )
             self.update_queue = dispatcher.update_queue
             self.__exception_event = dispatcher.exception_event
             self.persistence = dispatcher.persistence
@@ -210,32 +219,36 @@ class Updater:
         self.__lock = Lock()
         self.__threads: List[Thread] = []
 
-    def _init_thread(self, target: Callable, name: str, *args: Any, **kwargs: Any) -> None:
-        thr = Thread(target=self._thread_wrapper,
-                     name="Bot:{}:{}".format(self.bot.id, name),
-                     args=(target,) + args,
-                     kwargs=kwargs)
+    def _init_thread(self, target: Callable, name: str, *args: object, **kwargs: object) -> None:
+        thr = Thread(
+            target=self._thread_wrapper,
+            name=f"Bot:{self.bot.id}:{name}",
+            args=(target,) + args,
+            kwargs=kwargs,
+        )
         thr.start()
         self.__threads.append(thr)
 
-    def _thread_wrapper(self, target: Callable, *args: Any, **kwargs: Any) -> None:
+    def _thread_wrapper(self, target: Callable, *args: object, **kwargs: object) -> None:
         thr_name = current_thread().name
-        self.logger.debug('{} - started'.format(thr_name))
+        self.logger.debug('%s - started', thr_name)
         try:
             target(*args, **kwargs)
         except Exception:
             self.__exception_event.set()
             self.logger.exception('unhandled exception in %s', thr_name)
             raise
-        self.logger.debug('{} - ended'.format(thr_name))
+        self.logger.debug('%s - ended', thr_name)
 
-    def start_polling(self,
-                      poll_interval: float = 0.0,
-                      timeout: float = 10,
-                      clean: bool = False,
-                      bootstrap_retries: int = -1,
-                      read_latency: float = 2.,
-                      allowed_updates: List[str] = None) -> Optional[Queue]:
+    def start_polling(
+        self,
+        poll_interval: float = 0.0,
+        timeout: float = 10,
+        clean: bool = False,
+        bootstrap_retries: int = -1,
+        read_latency: float = 2.0,
+        allowed_updates: List[str] = None,
+    ) -> Optional[Queue]:
         """Starts polling updates from Telegram.
 
         Args:
@@ -270,9 +283,17 @@ class Updater:
                 dispatcher_ready = Event()
                 polling_ready = Event()
                 self._init_thread(self.dispatcher.start, "dispatcher", ready=dispatcher_ready)
-                self._init_thread(self._start_polling, "updater", poll_interval, timeout,
-                                  read_latency, bootstrap_retries, clean, allowed_updates,
-                                  ready=polling_ready)
+                self._init_thread(
+                    self._start_polling,
+                    "updater",
+                    poll_interval,
+                    timeout,
+                    read_latency,
+                    bootstrap_retries,
+                    clean,
+                    allowed_updates,
+                    ready=polling_ready,
+                )
 
                 self.logger.debug('Waiting for Dispatcher and polling to start')
                 dispatcher_ready.wait()
@@ -282,17 +303,19 @@ class Updater:
                 return self.update_queue
             return None
 
-    def start_webhook(self,
-                      listen: str = '127.0.0.1',
-                      port: int = 80,
-                      url_path: str = '',
-                      cert: str = None,
-                      key: str = None,
-                      clean: bool = False,
-                      bootstrap_retries: int = 0,
-                      webhook_url: str = None,
-                      allowed_updates: List[str] = None,
-                      force_event_loop: bool = False) -> Optional[Queue]:
+    def start_webhook(
+        self,
+        listen: str = '127.0.0.1',
+        port: int = 80,
+        url_path: str = '',
+        cert: str = None,
+        key: str = None,
+        clean: bool = False,
+        bootstrap_retries: int = 0,
+        webhook_url: str = None,
+        allowed_updates: List[str] = None,
+        force_event_loop: bool = False,
+    ) -> Optional[Queue]:
         """
         Starts a small http server to listen for updates via webhook. If cert
         and key are not provided, the webhook will be started directly on
@@ -344,9 +367,21 @@ class Updater:
                 dispatcher_ready = Event()
                 self.job_queue.start()
                 self._init_thread(self.dispatcher.start, "dispatcher", dispatcher_ready)
-                self._init_thread(self._start_webhook, "updater", listen, port, url_path, cert,
-                                  key, bootstrap_retries, clean, webhook_url, allowed_updates,
-                                  ready=webhook_ready, force_event_loop=force_event_loop)
+                self._init_thread(
+                    self._start_webhook,
+                    "updater",
+                    listen,
+                    port,
+                    url_path,
+                    cert,
+                    key,
+                    bootstrap_retries,
+                    clean,
+                    webhook_url,
+                    allowed_updates,
+                    ready=webhook_ready,
+                    force_event_loop=force_event_loop,
+                )
 
                 self.logger.debug('Waiting for Dispatcher and Webhook to start')
                 webhook_ready.wait()
@@ -357,8 +392,16 @@ class Updater:
             return None
 
     @no_type_check
-    def _start_polling(self, poll_interval, timeout, read_latency, bootstrap_retries, clean,
-                       allowed_updates, ready=None):  # pragma: no cover
+    def _start_polling(
+        self,
+        poll_interval,
+        timeout,
+        read_latency,
+        bootstrap_retries,
+        clean,
+        allowed_updates,
+        ready=None,
+    ):  # pragma: no cover
         # Thread target of thread 'updater'. Runs in background, pulls
         # updates from Telegram and inserts them in the update queue of the
         # Dispatcher.
@@ -370,10 +413,12 @@ class Updater:
         self.logger.debug('Bootstrap done')
 
         def polling_action_cb():
-            updates = self.bot.get_updates(self.last_update_id,
-                                           timeout=timeout,
-                                           read_latency=read_latency,
-                                           allowed_updates=allowed_updates)
+            updates = self.bot.get_updates(
+                self.last_update_id,
+                timeout=timeout,
+                read_latency=read_latency,
+                allowed_updates=allowed_updates,
+            )
 
             if updates:
                 if not self.running:
@@ -393,8 +438,9 @@ class Updater:
         if ready is not None:
             ready.set()
 
-        self._network_loop_retry(polling_action_cb, polling_onerr_cb, 'getting Updates',
-                                 poll_interval)
+        self._network_loop_retry(
+            polling_action_cb, polling_onerr_cb, 'getting Updates', poll_interval
+        )
 
     @no_type_check
     def _network_loop_retry(self, action_cb, onerr_cb, description, interval):
@@ -418,9 +464,9 @@ class Updater:
             try:
                 if not action_cb():
                     break
-            except RetryAfter as e:
-                self.logger.info('%s', e)
-                cur_interval = 0.5 + e.retry_after
+            except RetryAfter as exc:
+                self.logger.info('%s', exc)
+                cur_interval = 0.5 + exc.retry_after
             except TimedOut as toe:
                 self.logger.debug('Timed out %s: %s', description, toe)
                 # If failure is due to timeout, we should retry asap.
@@ -428,9 +474,9 @@ class Updater:
             except InvalidToken as pex:
                 self.logger.error('Invalid token; aborting')
                 raise pex
-            except TelegramError as te:
-                self.logger.error('Error while %s: %s', description, te)
-                onerr_cb(te)
+            except TelegramError as telegram_exc:
+                self.logger.error('Error while %s: %s', description, telegram_exc)
+                onerr_cb(telegram_exc)
                 cur_interval = self._increase_poll_interval(cur_interval)
             else:
                 cur_interval = interval
@@ -450,12 +496,24 @@ class Updater:
         return current_interval
 
     @no_type_check
-    def _start_webhook(self, listen, port, url_path, cert, key, bootstrap_retries, clean,
-                       webhook_url, allowed_updates, ready=None, force_event_loop=False):
+    def _start_webhook(
+        self,
+        listen,
+        port,
+        url_path,
+        cert,
+        key,
+        bootstrap_retries,
+        clean,
+        webhook_url,
+        allowed_updates,
+        ready=None,
+        force_event_loop=False,
+    ):
         self.logger.debug('Updater thread started (webhook)')
         use_ssl = cert is not None and key is not None
         if not url_path.startswith('/'):
-            url_path = '/{}'.format(url_path)
+            url_path = f'/{url_path}'
 
         # Create Tornado app instance
         app = WebhookAppClass(url_path, self.bot, self.update_queue)
@@ -466,8 +524,8 @@ class Updater:
             try:
                 ssl_ctx = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
                 ssl_ctx.load_cert_chain(cert, key)
-            except ssl.SSLError:
-                raise TelegramError('Invalid SSL Certificate')
+            except ssl.SSLError as exc:
+                raise TelegramError('Invalid SSL Certificate') from exc
         else:
             ssl_ctx = None
 
@@ -479,29 +537,29 @@ class Updater:
             if not webhook_url:
                 webhook_url = self._gen_webhook_url(listen, port, url_path)
 
-            self._bootstrap(max_retries=bootstrap_retries,
-                            clean=clean,
-                            webhook_url=webhook_url,
-                            cert=open(cert, 'rb'),
-                            allowed_updates=allowed_updates)
+            self._bootstrap(
+                max_retries=bootstrap_retries,
+                clean=clean,
+                webhook_url=webhook_url,
+                cert=open(cert, 'rb'),
+                allowed_updates=allowed_updates,
+            )
         elif clean:
-            self.logger.warning("cleaning updates is not supported if "
-                                "SSL-termination happens elsewhere; skipping")
+            self.logger.warning(
+                "cleaning updates is not supported if "
+                "SSL-termination happens elsewhere; skipping"
+            )
 
         self.httpd.serve_forever(force_event_loop=force_event_loop, ready=ready)
 
     @staticmethod
     def _gen_webhook_url(listen: str, port: int, url_path: str) -> str:
-        return 'https://{listen}:{port}{path}'.format(listen=listen, port=port, path=url_path)
+        return f'https://{listen}:{port}{url_path}'
 
     @no_type_check
-    def _bootstrap(self,
-                   max_retries,
-                   clean,
-                   webhook_url,
-                   allowed_updates,
-                   cert=None,
-                   bootstrap_interval=5):
+    def _bootstrap(
+        self, max_retries, clean, webhook_url, allowed_updates, cert=None, bootstrap_interval=5
+    ):
         retries = [0]
 
         def bootstrap_del_webhook():
@@ -516,16 +574,17 @@ class Updater:
             return False
 
         def bootstrap_set_webhook():
-            self.bot.set_webhook(url=webhook_url,
-                                 certificate=cert,
-                                 allowed_updates=allowed_updates)
+            self.bot.set_webhook(
+                url=webhook_url, certificate=cert, allowed_updates=allowed_updates
+            )
             return False
 
         def bootstrap_onerr_cb(exc):
             if not isinstance(exc, Unauthorized) and (max_retries < 0 or retries[0] < max_retries):
                 retries[0] += 1
-                self.logger.warning('Failed bootstrap phase; try=%s max_retries=%s', retries[0],
-                                    max_retries)
+                self.logger.warning(
+                    'Failed bootstrap phase; try=%s max_retries=%s', retries[0], max_retries
+                )
             else:
                 self.logger.error('Failed bootstrap phase after %s retries (%s)', retries[0], exc)
                 raise exc
@@ -535,22 +594,34 @@ class Updater:
         # We also take this chance to delete pre-configured webhook if this is a polling Updater.
         # NOTE: We don't know ahead if a webhook is configured, so we just delete.
         if clean or not webhook_url:
-            self._network_loop_retry(bootstrap_del_webhook, bootstrap_onerr_cb,
-                                     'bootstrap del webhook', bootstrap_interval)
+            self._network_loop_retry(
+                bootstrap_del_webhook,
+                bootstrap_onerr_cb,
+                'bootstrap del webhook',
+                bootstrap_interval,
+            )
             retries[0] = 0
 
         # Clean pending messages, if requested.
         if clean:
-            self._network_loop_retry(bootstrap_clean_updates, bootstrap_onerr_cb,
-                                     'bootstrap clean updates', bootstrap_interval)
+            self._network_loop_retry(
+                bootstrap_clean_updates,
+                bootstrap_onerr_cb,
+                'bootstrap clean updates',
+                bootstrap_interval,
+            )
             retries[0] = 0
             sleep(1)
 
         # Restore/set webhook settings, if needed. Again, we don't know ahead if a webhook is set,
         # so we set it anyhow.
         if webhook_url:
-            self._network_loop_retry(bootstrap_set_webhook, bootstrap_onerr_cb,
-                                     'bootstrap set webhook', bootstrap_interval)
+            self._network_loop_retry(
+                bootstrap_set_webhook,
+                bootstrap_onerr_cb,
+                'bootstrap set webhook',
+                bootstrap_interval,
+            )
 
     def stop(self) -> None:
         """Stops the polling/webhook thread, the dispatcher and the job queue."""
@@ -573,9 +644,11 @@ class Updater:
     @no_type_check
     def _stop_httpd(self) -> None:
         if self.httpd:
-            self.logger.debug('Waiting for current webhook connection to be '
-                              'closed... Send a Telegram message to the bot to exit '
-                              'immediately.')
+            self.logger.debug(
+                'Waiting for current webhook connection to be '
+                'closed... Send a Telegram message to the bot to exit '
+                'immediately.'
+            )
             self.httpd.shutdown()
             self.httpd = None
 
@@ -587,17 +660,18 @@ class Updater:
     @no_type_check
     def _join_threads(self) -> None:
         for thr in self.__threads:
-            self.logger.debug('Waiting for {} thread to end'.format(thr.name))
+            self.logger.debug('Waiting for %s thread to end', thr.name)
             thr.join()
-            self.logger.debug('{} thread has ended'.format(thr.name))
+            self.logger.debug('%s thread has ended', thr.name)
         self.__threads = []
 
     @no_type_check
     def signal_handler(self, signum, frame) -> None:
         self.is_idle = False
         if self.running:
-            self.logger.info('Received signal {} ({}), stopping...'.format(
-                signum, get_signal_name(signum)))
+            self.logger.info(
+                'Received signal %s (%s), stopping...', signum, get_signal_name(signum)
+            )
             if self.persistence:
                 # Update user_data, chat_data and bot_data before flushing
                 self.dispatcher.update_persistence()
@@ -607,7 +681,9 @@ class Updater:
                 self.user_sig_handler(signum, frame)
         else:
             self.logger.warning('Exiting immediately!')
+            # pylint: disable=C0415,W0212
             import os
+
             os._exit(1)
 
     def idle(self, stop_signals: Union[List, Tuple] = (SIGINT, SIGTERM, SIGABRT)) -> None:
