@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,10 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram Contact."""
 
-from telegram import TelegramObject
 from typing import Any
 
+from telegram import TelegramObject
+
 
 class Contact(TelegramObject):
     """This object represents a phone contact.
@@ -28,13 +29,6 @@ class Contact(TelegramObject):
     Objects of this class are comparable in terms of equality. Two objects of this class are
     considered equal, if their :attr:`phone_number` is equal.
 
-    Attributes:
-        phone_number (:obj:`str`): Contact's phone number.
-        first_name (:obj:`str`): Contact's first name.
-        last_name (:obj:`str`): Optional. Contact's last name.
-        user_id (:obj:`int`): Optional. Contact's user identifier in Telegram.
-        vcard (:obj:`str`): Optional. Additional data about the contact in the form of a vCard.
-
     Args:
         phone_number (:obj:`str`): Contact's phone number.
         first_name (:obj:`str`): Contact's first name.
@@ -43,15 +37,24 @@ class Contact(TelegramObject):
         vcard (:obj:`str`, optional): Additional data about the contact in the form of a vCard.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        phone_number (:obj:`str`): Contact's phone number.
+        first_name (:obj:`str`): Contact's first name.
+        last_name (:obj:`str`): Optional. Contact's last name.
+        user_id (:obj:`int`): Optional. Contact's user identifier in Telegram.
+        vcard (:obj:`str`): Optional. Additional data about the contact in the form of a vCard.
+
     """
 
-    def __init__(self,
-                 phone_number: str,
-                 first_name: str,
-                 last_name: str = None,
-                 user_id: int = None,
-                 vcard: str = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        phone_number: str,
+        first_name: str,
+        last_name: str = None,
+        user_id: int = None,
+        vcard: str = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.phone_number = str(phone_number)
         self.first_name = first_name
