@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,8 +18,10 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram InlineKeyboardButton."""
 
+from typing import TYPE_CHECKING, Any
+
 from telegram import TelegramObject
-from typing import Any, TYPE_CHECKING
+
 if TYPE_CHECKING:
     from telegram import CallbackGame, LoginUrl
 
@@ -36,27 +38,10 @@ class InlineKeyboardButton(TelegramObject):
         You must use exactly one of the optional fields. Mind that :attr:`callback_game` is not
         working as expected. Putting a game short name in it might, but is not guaranteed to work.
 
-    Attributes:
-        text (:obj:`str`): Label text on the button.
-        url (:obj:`str`): Optional. HTTP or tg:// url to be opened when button is pressed.
-        login_url (:class:`telegram.LoginUrl`) Optional. An HTTP URL used to automatically
-            authorize the user. Can be used as a replacement for the Telegram Login Widget.
-        callback_data (:obj:`str`): Optional. Data to be sent in a callback query to the bot when
-            button is pressed, UTF-8 1-64 bytes.
-        switch_inline_query (:obj:`str`): Optional. Will prompt the user to select one of their
-            chats, open that chat and insert the bot's username and the specified inline query in
-            the input field. Can be empty, in which case just the bot’s username will be inserted.
-        switch_inline_query_current_chat (:obj:`str`): Optional. Will insert the bot's username and
-            the specified inline query in the current chat's input field. Can be empty, in which
-            case just the bot’s username will be inserted.
-        callback_game (:class:`telegram.CallbackGame`): Optional. Description of the game that will
-            be launched when the user presses the button.
-        pay (:obj:`bool`): Optional. Specify True, to send a Pay button.
-
     Args:
         text (:obj:`str`): Label text on the button.
         url (:obj:`str`): HTTP or tg:// url to be opened when button is pressed.
-        login_url (:class:`telegram.LoginUrl`, optional) An HTTP URL used to automatically
+        login_url (:class:`telegram.LoginUrl`, optional): An HTTP URL used to automatically
             authorize the user. Can be used as a replacement for the Telegram Login Widget.
         callback_data (:obj:`str`, optional): Data to be sent in a callback query to the bot when
             button is pressed, UTF-8 1-64 bytes.
@@ -79,18 +64,37 @@ class InlineKeyboardButton(TelegramObject):
             must always be the ``first`` button in the first row.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        text (:obj:`str`): Label text on the button.
+        url (:obj:`str`): Optional. HTTP or tg:// url to be opened when button is pressed.
+        login_url (:class:`telegram.LoginUrl`): Optional. An HTTP URL used to automatically
+            authorize the user. Can be used as a replacement for the Telegram Login Widget.
+        callback_data (:obj:`str`): Optional. Data to be sent in a callback query to the bot when
+            button is pressed, UTF-8 1-64 bytes.
+        switch_inline_query (:obj:`str`): Optional. Will prompt the user to select one of their
+            chats, open that chat and insert the bot's username and the specified inline query in
+            the input field. Can be empty, in which case just the bot’s username will be inserted.
+        switch_inline_query_current_chat (:obj:`str`): Optional. Will insert the bot's username and
+            the specified inline query in the current chat's input field. Can be empty, in which
+            case just the bot’s username will be inserted.
+        callback_game (:class:`telegram.CallbackGame`): Optional. Description of the game that will
+            be launched when the user presses the button.
+        pay (:obj:`bool`): Optional. Specify :obj:`True`, to send a Pay button.
+
     """
 
-    def __init__(self,
-                 text: str,
-                 url: str = None,
-                 callback_data: str = None,
-                 switch_inline_query: str = None,
-                 switch_inline_query_current_chat: str = None,
-                 callback_game: 'CallbackGame' = None,
-                 pay: bool = None,
-                 login_url: 'LoginUrl' = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        text: str,
+        url: str = None,
+        callback_data: str = None,
+        switch_inline_query: str = None,
+        switch_inline_query_current_chat: str = None,
+        callback_game: 'CallbackGame' = None,
+        pay: bool = None,
+        login_url: 'LoginUrl' = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.text = text
 
