@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,11 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram InlineKeyboardMarkup."""
 
-from telegram import ReplyMarkup, InlineKeyboardButton
+from typing import TYPE_CHECKING, Any, List, Optional
+
+from telegram import InlineKeyboardButton, ReplyMarkup
 from telegram.utils.types import JSONDict
-from typing import Any, List, Optional, TYPE_CHECKING
+
 if TYPE_CHECKING:
     from telegram import Bot
 
@@ -32,18 +34,18 @@ class InlineKeyboardMarkup(ReplyMarkup):
     Objects of this class are comparable in terms of equality. Two objects of this class are
     considered equal, if their the size of :attr:`inline_keyboard` and all the buttons are equal.
 
-    Attributes:
-        inline_keyboard (List[List[:class:`telegram.InlineKeyboardButton`]]): List of button rows,
-            each represented by a list of InlineKeyboardButton objects.
-
     Args:
         inline_keyboard (List[List[:class:`telegram.InlineKeyboardButton`]]): List of button rows,
             each represented by a list of InlineKeyboardButton objects.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        inline_keyboard (List[List[:class:`telegram.InlineKeyboardButton`]]): List of button rows,
+            each represented by a list of InlineKeyboardButton objects.
+
     """
 
-    def __init__(self, inline_keyboard: List[List[InlineKeyboardButton]], **kwargs: Any):
+    def __init__(self, inline_keyboard: List[List[InlineKeyboardButton]], **_kwargs: Any):
         # Required
         self.inline_keyboard = inline_keyboard
 
@@ -57,8 +59,7 @@ class InlineKeyboardMarkup(ReplyMarkup):
         return data
 
     @classmethod
-    def de_json(cls, data: Optional[JSONDict],
-                bot: 'Bot') -> Optional['InlineKeyboardMarkup']:
+    def de_json(cls, data: Optional[JSONDict], bot: 'Bot') -> Optional['InlineKeyboardMarkup']:
         data = cls.parse_data(data)
 
         if not data:
@@ -76,7 +77,7 @@ class InlineKeyboardMarkup(ReplyMarkup):
         return cls(keyboard)
 
     @classmethod
-    def from_button(cls, button: InlineKeyboardButton, **kwargs: Any) -> 'InlineKeyboardMarkup':
+    def from_button(cls, button: InlineKeyboardButton, **kwargs: object) -> 'InlineKeyboardMarkup':
         """Shortcut for::
 
             InlineKeyboardMarkup([[button]], **kwargs)
@@ -91,8 +92,9 @@ class InlineKeyboardMarkup(ReplyMarkup):
         return cls([[button]], **kwargs)
 
     @classmethod
-    def from_row(cls, button_row: List[InlineKeyboardButton],
-                 **kwargs: Any) -> 'InlineKeyboardMarkup':
+    def from_row(
+        cls, button_row: List[InlineKeyboardButton], **kwargs: object
+    ) -> 'InlineKeyboardMarkup':
         """Shortcut for::
 
             InlineKeyboardMarkup([button_row], **kwargs)
@@ -108,8 +110,9 @@ class InlineKeyboardMarkup(ReplyMarkup):
         return cls([button_row], **kwargs)
 
     @classmethod
-    def from_column(cls, button_column: List[InlineKeyboardButton],
-                    **kwargs: Any) -> 'InlineKeyboardMarkup':
+    def from_column(
+        cls, button_column: List[InlineKeyboardButton], **kwargs: object
+    ) -> 'InlineKeyboardMarkup':
         """Shortcut for::
 
             InlineKeyboardMarkup([[button] for button in button_column], **kwargs)
@@ -136,7 +139,7 @@ class InlineKeyboardMarkup(ReplyMarkup):
                     if button != other.inline_keyboard[idx][jdx]:
                         return False
             return True
-        return super(InlineKeyboardMarkup, self).__eq__(other)  # pylint: disable=no-member
+        return super().__eq__(other)
 
     def __hash__(self) -> int:
         return hash(tuple(tuple(button for button in row) for row in self.inline_keyboard))
