@@ -22,7 +22,8 @@
 from typing import TYPE_CHECKING, Any, Optional, List, Union, Callable, ClassVar
 
 from telegram import Location, TelegramObject, User, constants
-from telegram.utils.types import JSONDict
+from telegram.utils.helpers import DEFAULT_NONE
+from telegram.utils.types import JSONDict, ODVInput
 
 if TYPE_CHECKING:
     from telegram import Bot, InlineQueryResult
@@ -103,7 +104,7 @@ class InlineQuery(TelegramObject):
         next_offset: str = None,
         switch_pm_text: str = None,
         switch_pm_parameter: str = None,
-        timeout: float = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
         current_offset: str = None,
         api_kwargs: JSONDict = None,
         auto_pagination: bool = False,
@@ -120,11 +121,11 @@ class InlineQuery(TelegramObject):
 
         Args:
             auto_pagination (:obj:`bool`, optional): If set to :obj:`True`, :attr:`offset` will be
-                passed as :attr:`current_offset` to :meth:telegram.Bot.answer_inline_query`.
+                passed as :attr:`current_offset` to :meth:`telegram.Bot.answer_inline_query`.
                 Defaults to :obj:`False`.
 
         Raises:
-            TypeError: If both :attr:`current_offset` and `auto_pagination` are supplied.
+            TypeError: If both :attr:`current_offset` and attr:`auto_pagination` are supplied.
         """
         if current_offset and auto_pagination:
             # We raise TypeError instead of ValueError for backwards compatibility with versions
