@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,12 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the classes that represent Telegram InlineQueryResultAudio."""
 
-from telegram import InlineQueryResult
-from telegram.utils.helpers import DEFAULT_NONE, DefaultValue
-from typing import Any, Union, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Union, Tuple, List
+
+from telegram import InlineQueryResult, MessageEntity
+from telegram.utils.helpers import DEFAULT_NONE
+from telegram.utils.types import ODVInput
+
 if TYPE_CHECKING:
     from telegram import InputMessageContent, ReplyMarkup
 
@@ -31,6 +34,25 @@ class InlineQueryResultAudio(InlineQueryResult):
     Alternatively, you can use :attr:`input_message_content` to send a message with the specified
     content instead of the audio.
 
+    Args:
+        id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
+        audio_url (:obj:`str`): A valid URL for the audio file.
+        title (:obj:`str`): Title.
+        performer (:obj:`str`, optional): Performer.
+        audio_duration (:obj:`str`, optional): Audio duration in seconds.
+        caption (:obj:`str`, optional): Caption, 0-1024 characters after entities parsing.
+        parse_mode (:obj:`str`, optional): Send Markdown or HTML, if you want Telegram apps to show
+            bold, italic, fixed-width text or inline URLs in the media caption. See the constants
+            in :class:`telegram.ParseMode` for the available modes.
+        caption_entities (List[:class:`telegram.MessageEntity`], optional): List of special
+            entities that appear in the caption, which can be specified instead of
+            :attr:`parse_mode`.
+        reply_markup (:class:`telegram.InlineKeyboardMarkup`, optional): Inline keyboard attached
+            to the message.
+        input_message_content (:class:`telegram.InputMessageContent`, optional): Content of the
+            message to be sent instead of the audio.
+        **kwargs (:obj:`dict`): Arbitrary keyword arguments.
+
     Attributes:
         type (:obj:`str`): 'audio'.
         id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
@@ -42,40 +64,30 @@ class InlineQueryResultAudio(InlineQueryResult):
         parse_mode (:obj:`str`): Optional. Send Markdown or HTML, if you want Telegram apps to show
             bold, italic, fixed-width text or inline URLs in the media caption. See the constants
             in :class:`telegram.ParseMode` for the available modes.
+        caption_entities (List[:class:`telegram.MessageEntity`]): Optional. List of special
+            entities that appear in the caption, which can be specified instead of
+            :attr:`parse_mode`.
         reply_markup (:class:`telegram.InlineKeyboardMarkup`): Optional. Inline keyboard attached
             to the message.
         input_message_content (:class:`telegram.InputMessageContent`): Optional. Content of the
             message to be sent instead of the audio.
 
-    Args:
-        id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
-        audio_url (:obj:`str`): A valid URL for the audio file.
-        title (:obj:`str`): Title.
-        performer (:obj:`str`, optional): Performer.
-        audio_duration (:obj:`str`, optional): Audio duration in seconds.
-        caption (:obj:`str`, optional): Caption, 0-1024 characters after entities parsing.
-        parse_mode (:obj:`str`, optional): Send Markdown or HTML, if you want Telegram apps to show
-            bold, italic, fixed-width text or inline URLs in the media caption. See the constants
-            in :class:`telegram.ParseMode` for the available modes.
-        reply_markup (:class:`telegram.InlineKeyboardMarkup`, optional): Inline keyboard attached
-            to the message.
-        input_message_content (:class:`telegram.InputMessageContent`, optional): Content of the
-            message to be sent instead of the audio.
-        **kwargs (:obj:`dict`): Arbitrary keyword arguments.
-
     """
 
-    def __init__(self,
-                 id: str,
-                 audio_url: str,
-                 title: str,
-                 performer: str = None,
-                 audio_duration: int = None,
-                 caption: str = None,
-                 reply_markup: 'ReplyMarkup' = None,
-                 input_message_content: 'InputMessageContent' = None,
-                 parse_mode: Union[str, DefaultValue] = DEFAULT_NONE,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        id: str,  # pylint: disable=W0622
+        audio_url: str,
+        title: str,
+        performer: str = None,
+        audio_duration: int = None,
+        caption: str = None,
+        reply_markup: 'ReplyMarkup' = None,
+        input_message_content: 'InputMessageContent' = None,
+        parse_mode: ODVInput[str] = DEFAULT_NONE,
+        caption_entities: Union[Tuple[MessageEntity, ...], List[MessageEntity]] = None,
+        **_kwargs: Any,
+    ):
 
         # Required
         super().__init__('audio', id)
@@ -87,5 +99,6 @@ class InlineQueryResultAudio(InlineQueryResult):
         self.audio_duration = audio_duration
         self.caption = caption
         self.parse_mode = parse_mode
+        self.caption_entities = caption_entities
         self.reply_markup = reply_markup
         self.input_message_content = input_message_content
