@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,8 +18,10 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the classes that represent Telegram InlineQueryResultGame."""
 
+from typing import TYPE_CHECKING, Any
+
 from telegram import InlineQueryResult
-from typing import Any, TYPE_CHECKING
+
 if TYPE_CHECKING:
     from telegram import ReplyMarkup
 
@@ -27,13 +29,6 @@ if TYPE_CHECKING:
 class InlineQueryResultGame(InlineQueryResult):
     """Represents a :class:`telegram.Game`.
 
-    Attributes:
-        type (:obj:`str`): 'game'.
-        id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
-        game_short_name (:obj:`str`): Short name of the game.
-        reply_markup (:class:`telegram.InlineKeyboardMarkup`): Optional. Inline keyboard attached
-            to the message.
-
     Args:
         id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
         game_short_name (:obj:`str`): Short name of the game.
@@ -41,16 +36,25 @@ class InlineQueryResultGame(InlineQueryResult):
             to the message.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        type (:obj:`str`): 'game'.
+        id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
+        game_short_name (:obj:`str`): Short name of the game.
+        reply_markup (:class:`telegram.InlineKeyboardMarkup`): Optional. Inline keyboard attached
+            to the message.
+
     """
 
-    def __init__(self,
-                 id: str,
-                 game_short_name: str,
-                 reply_markup: 'ReplyMarkup' = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        id: str,  # pylint: disable=W0622
+        game_short_name: str,
+        reply_markup: 'ReplyMarkup' = None,
+        **_kwargs: Any,
+    ):
         # Required
         super().__init__('game', id)
-        self.id = id
+        self.id = id  # pylint: disable=W0622
         self.game_short_name = game_short_name
 
         self.reply_markup = reply_markup
