@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,12 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the classes that represent Telegram InlineQueryResultMpeg4Gif."""
 
-from telegram import InlineQueryResult
-from telegram.utils.helpers import DEFAULT_NONE, DefaultValue
-from typing import Any, Union, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Union, Tuple, List
+
+from telegram import InlineQueryResult, MessageEntity
+from telegram.utils.helpers import DEFAULT_NONE
+from telegram.utils.types import ODVInput
+
 if TYPE_CHECKING:
     from telegram import InputMessageContent, ReplyMarkup
 
@@ -32,6 +35,30 @@ class InlineQueryResultMpeg4Gif(InlineQueryResult):
     use :attr:`input_message_content` to send a message with the specified content instead of the
     animation.
 
+    Args:
+        id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
+        mpeg4_url (:obj:`str`): A valid URL for the MP4 file. File size must not exceed 1MB.
+        mpeg4_width (:obj:`int`, optional): Video width.
+        mpeg4_height (:obj:`int`, optional): Video height.
+        mpeg4_duration (:obj:`int`, optional): Video duration.
+        thumb_url (:obj:`str`): URL of the static thumbnail (jpeg or gif) for the result.
+        thumb_mime_type (:obj:`str`): Optional. MIME type of the thumbnail, must be one of
+            ``'image/jpeg'``, ``'image/gif'``, or ``'video/mp4'``. Defaults to ``'image/jpeg'``.
+        title (:obj:`str`, optional): Title for the result.
+        caption (:obj:`str`, optional): Caption of the MPEG-4 file to be sent, 0-1024 characters
+            after entities parsing.
+        parse_mode (:obj:`str`, optional): Send Markdown or HTML, if you want Telegram apps to show
+            bold, italic, fixed-width text or inline URLs in the media caption. See the constants
+            in :class:`telegram.ParseMode` for the available modes.
+        caption_entities (List[:class:`telegram.MessageEntity`], optional): List of special
+            entities that appear in the caption, which can be specified instead of
+            :attr:`parse_mode`.
+        reply_markup (:class:`telegram.InlineKeyboardMarkup`, optional): Inline keyboard attached
+            to the message.
+        input_message_content (:class:`telegram.InputMessageContent`, optional): Content of the
+            message to be sent instead of the video animation.
+        **kwargs (:obj:`dict`): Arbitrary keyword arguments.
+
     Attributes:
         type (:obj:`str`): 'mpeg4_gif'.
         id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
@@ -48,48 +75,33 @@ class InlineQueryResultMpeg4Gif(InlineQueryResult):
         parse_mode (:obj:`str`): Optional. Send Markdown or HTML, if you want Telegram apps to show
             bold, italic, fixed-width text or inline URLs in the media caption. See the constants
             in :class:`telegram.ParseMode` for the available modes.
+        caption_entities (List[:class:`telegram.MessageEntity`]): Optional. List of special
+            entities that appear in the caption, which can be specified instead of
+            :attr:`parse_mode`.
         reply_markup (:class:`telegram.InlineKeyboardMarkup`): Optional. Inline keyboard attached
             to the message.
         input_message_content (:class:`telegram.InputMessageContent`): Optional. Content of the
             message to be sent instead of the video animation.
 
-    Args:
-        id (:obj:`str`): Unique identifier for this result, 1-64 bytes.
-        mpeg4_url (:obj:`str`): A valid URL for the MP4 file. File size must not exceed 1MB.
-        mpeg4_width (:obj:`int`, optional): Video width.
-        mpeg4_height (:obj:`int`, optional): Video height.
-        mpeg4_duration (:obj:`int`, optional): Video duration.
-        thumb_url (:obj:`str`): URL of the static thumbnail (jpeg or gif) for the result.
-        thumb_mime_type (:obj:`str`): Optional. MIME type of the thumbnail, must be one of
-            ``'image/jpeg'``, ``'image/gif'``, or ``'video/mp4'``. Defaults to ``'image/jpeg'``.
-        title (:obj:`str`, optional): Title for the result.
-        caption (:obj:`str`, optional): Caption of the MPEG-4 file to be sent, 0-1024 characters
-            after entities parsing.
-        parse_mode (:obj:`str`, optional): Send Markdown or HTML, if you want Telegram apps to show
-            bold, italic, fixed-width text or inline URLs in the media caption. See the constants
-            in :class:`telegram.ParseMode` for the available modes.
-        reply_markup (:class:`telegram.InlineKeyboardMarkup`, optional): Inline keyboard attached
-            to the message.
-        input_message_content (:class:`telegram.InputMessageContent`, optional): Content of the
-            message to be sent instead of the video animation.
-        **kwargs (:obj:`dict`): Arbitrary keyword arguments.
-
     """
 
-    def __init__(self,
-                 id: str,
-                 mpeg4_url: str,
-                 thumb_url: str,
-                 mpeg4_width: int = None,
-                 mpeg4_height: int = None,
-                 title: str = None,
-                 caption: str = None,
-                 reply_markup: 'ReplyMarkup' = None,
-                 input_message_content: 'InputMessageContent' = None,
-                 mpeg4_duration: int = None,
-                 parse_mode: Union[str, DefaultValue] = DEFAULT_NONE,
-                 thumb_mime_type: str = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        id: str,  # pylint: disable=W0622
+        mpeg4_url: str,
+        thumb_url: str,
+        mpeg4_width: int = None,
+        mpeg4_height: int = None,
+        title: str = None,
+        caption: str = None,
+        reply_markup: 'ReplyMarkup' = None,
+        input_message_content: 'InputMessageContent' = None,
+        mpeg4_duration: int = None,
+        parse_mode: ODVInput[str] = DEFAULT_NONE,
+        thumb_mime_type: str = None,
+        caption_entities: Union[Tuple[MessageEntity, ...], List[MessageEntity]] = None,
+        **_kwargs: Any,
+    ):
 
         # Required
         super().__init__('mpeg4_gif', id)
@@ -103,6 +115,7 @@ class InlineQueryResultMpeg4Gif(InlineQueryResult):
         self.title = title
         self.caption = caption
         self.parse_mode = parse_mode
+        self.caption_entities = caption_entities
         self.reply_markup = reply_markup
         self.input_message_content = input_message_content
         self.thumb_mime_type = thumb_mime_type
