@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,11 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the classes that represent Telegram InputTextMessageContent."""
 
-from telegram import InputMessageContent
-from telegram.utils.helpers import DEFAULT_NONE, DefaultValue
-from typing import Any, Union
+from typing import Any, Union, Tuple, List
+
+from telegram import InputMessageContent, MessageEntity
+from telegram.utils.helpers import DEFAULT_NONE
+from telegram.utils.types import JSONDict, ODVInput
 
 
 class InputTextMessageContent(InputMessageContent):
@@ -30,36 +32,54 @@ class InputTextMessageContent(InputMessageContent):
     Objects of this class are comparable in terms of equality. Two objects of this class are
     considered equal, if their :attr:`message_text` is equal.
 
-    Attributes:
-        message_text (:obj:`str`): Text of the message to be sent, 1-4096 characters after entities
-            parsing.
-        parse_mode (:obj:`str`): Optional. Send Markdown or HTML, if you want Telegram apps to show
-            bold, italic, fixed-width text or inline URLs in your bot's message. See the constants
-            in :class:`telegram.ParseMode` for the available modes.
-        disable_web_page_preview (:obj:`bool`): Optional. Disables link previews for links in the
-            sent message.
-
     Args:
         message_text (:obj:`str`): Text of the message to be sent, 1-4096 characters after entities
             parsing. Also found as :attr:`telegram.constants.MAX_MESSAGE_LENGTH`.
         parse_mode (:obj:`str`, optional): Send Markdown or HTML, if you want Telegram apps to show
             bold, italic, fixed-width text or inline URLs in your bot's message. See the constants
             in :class:`telegram.ParseMode` for the available modes.
+        entities (List[:class:`telegram.MessageEntity`], optional): List of special
+            entities that appear in the caption, which can be specified instead of
+            :attr:`parse_mode`.
         disable_web_page_preview (:obj:`bool`, optional): Disables link previews for links in the
             sent message.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        message_text (:obj:`str`): Text of the message to be sent, 1-4096 characters after entities
+            parsing.
+        parse_mode (:obj:`str`): Optional. Send Markdown or HTML, if you want Telegram apps to show
+            bold, italic, fixed-width text or inline URLs in your bot's message. See the constants
+            in :class:`telegram.ParseMode` for the available modes.
+        entities (List[:class:`telegram.MessageEntity`]): Optional. List of special
+            entities that appear in the caption, which can be specified instead of
+            :attr:`parse_mode`.
+        disable_web_page_preview (:obj:`bool`): Optional. Disables link previews for links in the
+            sent message.
+
     """
 
-    def __init__(self,
-                 message_text: str,
-                 parse_mode: Union[str, DefaultValue] = DEFAULT_NONE,
-                 disable_web_page_preview: Union[bool, DefaultValue] = DEFAULT_NONE,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        message_text: str,
+        parse_mode: ODVInput[str] = DEFAULT_NONE,
+        disable_web_page_preview: ODVInput[bool] = DEFAULT_NONE,
+        entities: Union[Tuple[MessageEntity, ...], List[MessageEntity]] = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.message_text = message_text
         # Optionals
         self.parse_mode = parse_mode
+        self.entities = entities
         self.disable_web_page_preview = disable_web_page_preview
 
         self._id_attrs = (self.message_text,)
+
+    def to_dict(self) -> JSONDict:
+        data = super().to_dict()
+
+        if self.entities:
+            data['entities'] = [ce.to_dict() for ce in self.entities]
+
+        return data
