@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -33,15 +33,7 @@ class MessageEntity(TelegramObject):
     usernames, URLs, etc.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`type`, :attr:`offset` and :attr`length` are equal.
-
-    Attributes:
-        type (:obj:`str`): Type of the entity.
-        offset (:obj:`int`): Offset in UTF-16 code units to the start of the entity.
-        length (:obj:`int`): Length of the entity in UTF-16 code units.
-        url (:obj:`str`): Optional. Url that will be opened after user taps on the text.
-        user (:class:`telegram.User`): Optional. The mentioned user.
-        language (:obj:`str`): Optional. Programming language of the entity text.
+    considered equal, if their :attr:`type`, :attr:`offset` and :attr:`length` are equal.
 
     Args:
         type (:obj:`str`): Type of the entity. Can be mention (@username), hashtag, bot_command,
@@ -57,6 +49,14 @@ class MessageEntity(TelegramObject):
         language (:obj:`str`, optional): For :attr:`PRE` only, the programming language of
             the entity text.
 
+    Attributes:
+        type (:obj:`str`): Type of the entity.
+        offset (:obj:`int`): Offset in UTF-16 code units to the start of the entity.
+        length (:obj:`int`): Length of the entity in UTF-16 code units.
+        url (:obj:`str`): Optional. Url that will be opened after user taps on the text.
+        user (:class:`telegram.User`): Optional. The mentioned user.
+        language (:obj:`str`): Optional. Programming language of the entity text.
+
     """
 
     def __init__(
