@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,12 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram PreCheckoutQuery."""
 
-from telegram import TelegramObject, User, OrderInfo
-from telegram.utils.types import JSONDict
-from typing import Any, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Optional
+
+from telegram import OrderInfo, TelegramObject, User
+from telegram.utils.helpers import DEFAULT_NONE
+from telegram.utils.types import JSONDict, ODVInput
+
 if TYPE_CHECKING:
     from telegram import Bot
 
@@ -32,18 +35,7 @@ class PreCheckoutQuery(TelegramObject):
     considered equal, if their :attr:`id` is equal.
 
     Note:
-        * In Python `from` is a reserved word, use `from_user` instead.
-
-    Attributes:
-        id (:obj:`str`): Unique query identifier.
-        from_user (:class:`telegram.User`): User who sent the query.
-        currency (:obj:`str`): Three-letter ISO 4217 currency code.
-        total_amount (:obj:`int`): Total price in the smallest units of the currency.
-        invoice_payload (:obj:`str`): Bot specified invoice payload.
-        shipping_option_id (:obj:`str`): Optional. Identifier of the shipping option chosen by the
-            user.
-        order_info (:class:`telegram.OrderInfo`): Optional. Order info provided by the user.
-        bot (:class:`telegram.Bot`): Optional. The Bot to use for instance methods.
+        In Python `from` is a reserved word, use `from_user` instead.
 
     Args:
         id (:obj:`str`): Unique query identifier.
@@ -62,19 +54,32 @@ class PreCheckoutQuery(TelegramObject):
         bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        id (:obj:`str`): Unique query identifier.
+        from_user (:class:`telegram.User`): User who sent the query.
+        currency (:obj:`str`): Three-letter ISO 4217 currency code.
+        total_amount (:obj:`int`): Total price in the smallest units of the currency.
+        invoice_payload (:obj:`str`): Bot specified invoice payload.
+        shipping_option_id (:obj:`str`): Optional. Identifier of the shipping option chosen by the
+            user.
+        order_info (:class:`telegram.OrderInfo`): Optional. Order info provided by the user.
+        bot (:class:`telegram.Bot`): Optional. The Bot to use for instance methods.
+
     """
 
-    def __init__(self,
-                 id: str,
-                 from_user: User,
-                 currency: str,
-                 total_amount: int,
-                 invoice_payload: str,
-                 shipping_option_id: str = None,
-                 order_info: OrderInfo = None,
-                 bot: 'Bot' = None,
-                 **kwargs: Any):
-        self.id = id
+    def __init__(
+        self,
+        id: str,  # pylint: disable=W0622
+        from_user: User,
+        currency: str,
+        total_amount: int,
+        invoice_payload: str,
+        shipping_option_id: str = None,
+        order_info: OrderInfo = None,
+        bot: 'Bot' = None,
+        **_kwargs: Any,
+    ):
+        self.id = id  # pylint: disable=C0103
         self.from_user = from_user
         self.currency = currency
         self.total_amount = total_amount
@@ -98,21 +103,25 @@ class PreCheckoutQuery(TelegramObject):
 
         return cls(bot=bot, **data)
 
-    def answer(self, *args: Any, **kwargs: Any) -> bool:
+    def answer(  # pylint: disable=C0103
+        self,
+        ok: bool,
+        error_message: str = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
         """Shortcut for::
 
             bot.answer_pre_checkout_query(update.pre_checkout_query.id, *args, **kwargs)
 
-        Args:
-            ok (:obj:`bool`): Specify :obj:`True` if everything is alright
-                (goods are available, etc.) and the bot is ready to proceed with the order.
-                Use :obj:`False` if there are any problems.
-            error_message (:obj:`str`, optional): Required if ok is :obj:`False`. Error message in
-                human readable form that explains the reason for failure to proceed with the
-                checkout (e.g. "Sorry, somebody just bought the last of our amazing black T-shirts
-                while you were busy filling out your payment details. Please choose a different
-                color or garment!"). Telegram will display this message to the user.
-            **kwargs (:obj:`dict`): Arbitrary keyword arguments.
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.answer_pre_checkout_query`.
 
         """
-        return self.bot.answer_pre_checkout_query(self.id, *args, **kwargs)
+        return self.bot.answer_pre_checkout_query(
+            pre_checkout_query_id=self.id,
+            ok=ok,
+            error_message=error_message,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
