@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -30,13 +30,6 @@ class ReplyKeyboardMarkup(ReplyMarkup):
     Objects of this class are comparable in terms of equality. Two objects of this class are
     considered equal, if their the size of :attr:`keyboard` and all the buttons are equal.
 
-    Attributes:
-        keyboard (List[List[:class:`telegram.KeyboardButton` | :obj:`str`]]): Array of button rows.
-        resize_keyboard (:obj:`bool`): Optional. Requests clients to resize the keyboard.
-        one_time_keyboard (:obj:`bool`): Optional. Requests clients to hide the keyboard as soon as
-            it's been used.
-        selective (:obj:`bool`): Optional. Show the keyboard to specific users only.
-
     Example:
         A user requests to change the bot's language, bot replies to the request with a keyboard
         to select the new language. Other users in the group don't see the keyboard.
@@ -63,6 +56,13 @@ class ReplyKeyboardMarkup(ReplyMarkup):
 
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        keyboard (List[List[:class:`telegram.KeyboardButton` | :obj:`str`]]): Array of button rows.
+        resize_keyboard (:obj:`bool`): Optional. Requests clients to resize the keyboard.
+        one_time_keyboard (:obj:`bool`): Optional. Requests clients to hide the keyboard as soon as
+            it's been used.
+        selective (:obj:`bool`): Optional. Show the keyboard to specific users only.
+
     """
 
     def __init__(
@@ -110,7 +110,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         resize_keyboard: bool = False,
         one_time_keyboard: bool = False,
         selective: bool = False,
-        **kwargs: Any,
+        **kwargs: object,
     ) -> 'ReplyKeyboardMarkup':
         """Shortcut for::
 
@@ -155,7 +155,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         resize_keyboard: bool = False,
         one_time_keyboard: bool = False,
         selective: bool = False,
-        **kwargs: Any,
+        **kwargs: object,
     ) -> 'ReplyKeyboardMarkup':
         """Shortcut for::
 
@@ -201,7 +201,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         resize_keyboard: bool = False,
         one_time_keyboard: bool = False,
         selective: bool = False,
-        **kwargs: Any,
+        **kwargs: object,
     ) -> 'ReplyKeyboardMarkup':
         """Shortcut for::
 
