@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,14 +18,23 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram Update."""
 
-from telegram import (Message, TelegramObject, InlineQuery, ChosenInlineResult,
-                      CallbackQuery, ShippingQuery, PreCheckoutQuery, Poll)
+from typing import TYPE_CHECKING, Any, Optional
+
+from telegram import (
+    CallbackQuery,
+    ChosenInlineResult,
+    InlineQuery,
+    Message,
+    Poll,
+    PreCheckoutQuery,
+    ShippingQuery,
+    TelegramObject,
+)
 from telegram.poll import PollAnswer
 from telegram.utils.types import JSONDict
-from typing import Any, Optional, TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from telegram import Bot, User, Chat  # noqa
+    from telegram import Bot, Chat, User  # noqa
 
 
 class Update(TelegramObject):
@@ -37,25 +46,6 @@ class Update(TelegramObject):
     Note:
         At most one of the optional parameters can be present in any given update.
 
-    Attributes:
-        update_id (:obj:`int`): The update's unique identifier.
-        message (:class:`telegram.Message`): Optional. New incoming message.
-        edited_message (:class:`telegram.Message`): Optional. New version of a message.
-        channel_post (:class:`telegram.Message`): Optional. New incoming channel post.
-        edited_channel_post (:class:`telegram.Message`): Optional. New version of a channel post.
-        inline_query (:class:`telegram.InlineQuery`): Optional. New incoming inline query.
-        chosen_inline_result (:class:`telegram.ChosenInlineResult`): Optional. The result of an
-            inline query that was chosen by a user.
-        callback_query (:class:`telegram.CallbackQuery`): Optional. New incoming callback query.
-        shipping_query (:class:`telegram.ShippingQuery`): Optional. New incoming shipping query.
-        pre_checkout_query (:class:`telegram.PreCheckoutQuery`): Optional. New incoming
-            pre-checkout query.
-        poll (:class:`telegram.Poll`): Optional. New poll state. Bots receive only updates
-            about stopped polls and polls, which are sent by the bot.
-        poll_answer (:class:`telegram.PollAnswer`): Optional. A user changed their answer
-            in a non-anonymous poll. Bots receive new votes only in polls that were sent
-            by the bot itself.
-
     Args:
         update_id (:obj:`int`): The update's unique identifier. Update identifiers start from a
             certain positive number and increase sequentially. This ID becomes especially handy if
@@ -86,22 +76,43 @@ class Update(TelegramObject):
             by the bot itself.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
+    Attributes:
+        update_id (:obj:`int`): The update's unique identifier.
+        message (:class:`telegram.Message`): Optional. New incoming message.
+        edited_message (:class:`telegram.Message`): Optional. New version of a message.
+        channel_post (:class:`telegram.Message`): Optional. New incoming channel post.
+        edited_channel_post (:class:`telegram.Message`): Optional. New version of a channel post.
+        inline_query (:class:`telegram.InlineQuery`): Optional. New incoming inline query.
+        chosen_inline_result (:class:`telegram.ChosenInlineResult`): Optional. The result of an
+            inline query that was chosen by a user.
+        callback_query (:class:`telegram.CallbackQuery`): Optional. New incoming callback query.
+        shipping_query (:class:`telegram.ShippingQuery`): Optional. New incoming shipping query.
+        pre_checkout_query (:class:`telegram.PreCheckoutQuery`): Optional. New incoming
+            pre-checkout query.
+        poll (:class:`telegram.Poll`): Optional. New poll state. Bots receive only updates
+            about stopped polls and polls, which are sent by the bot.
+        poll_answer (:class:`telegram.PollAnswer`): Optional. A user changed their answer
+            in a non-anonymous poll. Bots receive new votes only in polls that were sent
+            by the bot itself.
+
     """
 
-    def __init__(self,
-                 update_id: int,
-                 message: Message = None,
-                 edited_message: Message = None,
-                 channel_post: Message = None,
-                 edited_channel_post: Message = None,
-                 inline_query: InlineQuery = None,
-                 chosen_inline_result: ChosenInlineResult = None,
-                 callback_query: CallbackQuery = None,
-                 shipping_query: ShippingQuery = None,
-                 pre_checkout_query: PreCheckoutQuery = None,
-                 poll: Poll = None,
-                 poll_answer: PollAnswer = None,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        update_id: int,
+        message: Message = None,
+        edited_message: Message = None,
+        channel_post: Message = None,
+        edited_channel_post: Message = None,
+        inline_query: InlineQuery = None,
+        chosen_inline_result: ChosenInlineResult = None,
+        callback_query: CallbackQuery = None,
+        shipping_query: ShippingQuery = None,
+        pre_checkout_query: PreCheckoutQuery = None,
+        poll: Poll = None,
+        poll_answer: PollAnswer = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.update_id = int(update_id)
         # Optionals
@@ -239,7 +250,8 @@ class Update(TelegramObject):
         data['edited_message'] = Message.de_json(data.get('edited_message'), bot)
         data['inline_query'] = InlineQuery.de_json(data.get('inline_query'), bot)
         data['chosen_inline_result'] = ChosenInlineResult.de_json(
-            data.get('chosen_inline_result'), bot)
+            data.get('chosen_inline_result'), bot
+        )
         data['callback_query'] = CallbackQuery.de_json(data.get('callback_query'), bot)
         data['shipping_query'] = ShippingQuery.de_json(data.get('shipping_query'), bot)
         data['pre_checkout_query'] = PreCheckoutQuery.de_json(data.get('pre_checkout_query'), bot)
