@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 """This module facilitates the deprecation of functions."""
 
 import warnings
-from typing import Any, Callable, TypeVar
+from typing import Callable, TypeVar
 
 RT = TypeVar('RT')
 
@@ -42,7 +42,7 @@ def warn_deprecate_obj(old: str, new: str, stacklevel: int = 3) -> None:
 def deprecate(func: Callable[..., RT], old: str, new: str) -> Callable[..., RT]:
     """Warn users invoking old to switch to the new function."""
 
-    def wrapped(*args: Any, **kwargs: Any) -> RT:
+    def wrapped(*args: object, **kwargs: object) -> RT:
         warn_deprecate_obj(old, new)
         return func(*args, **kwargs)
 
