@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -26,49 +26,64 @@ import warnings
 try:
     import ujson as json
 except ImportError:
-    import json
+    import json  # type: ignore[no-redef]
 
-import certifi
+from typing import Any, Union
+
+import certifi  # pylint: disable=E0401
 
 try:
     import telegram.vendor.ptb_urllib3.urllib3 as urllib3
     import telegram.vendor.ptb_urllib3.urllib3.contrib.appengine as appengine
     from telegram.vendor.ptb_urllib3.urllib3.connection import HTTPConnection
-    from telegram.vendor.ptb_urllib3.urllib3.util.timeout import Timeout
     from telegram.vendor.ptb_urllib3.urllib3.fields import RequestField
+    from telegram.vendor.ptb_urllib3.urllib3.util.timeout import Timeout
 except ImportError:  # pragma: no cover
     try:
-        import urllib3
-        import urllib3.contrib.appengine as appengine
-        from urllib3.connection import HTTPConnection
-        from urllib3.util.timeout import Timeout
-        from urllib3.fields import RequestField
-        warnings.warn('python-telegram-bot is using upstream urllib3. This is allowed but not '
-                      'supported by python-telegram-bot maintainers.')
+        import urllib3  # type: ignore[no-redef]
+        import urllib3.contrib.appengine as appengine  # type: ignore[no-redef]
+        from urllib3.connection import HTTPConnection  # type: ignore[no-redef]
+        from urllib3.fields import RequestField  # type: ignore[no-redef]
+        from urllib3.util.timeout import Timeout  # type: ignore[no-redef]
+
+        warnings.warn(
+            'python-telegram-bot is using upstream urllib3. This is allowed but not '
+            'supported by python-telegram-bot maintainers.'
+        )
     except ImportError:
         warnings.warn(
             "python-telegram-bot wasn't properly installed. Please refer to README.rst on "
-            "how to properly install.")
+            "how to properly install."
+        )
         raise
 
-
-from telegram import (InputFile, TelegramError, InputMedia)
-from telegram.error import (Unauthorized, NetworkError, TimedOut, BadRequest, ChatMigrated,
-                            RetryAfter, InvalidToken, Conflict)
+# pylint: disable=C0412
+from telegram import InputFile, InputMedia, TelegramError
+from telegram.error import (
+    BadRequest,
+    ChatMigrated,
+    Conflict,
+    InvalidToken,
+    NetworkError,
+    RetryAfter,
+    TimedOut,
+    Unauthorized,
+)
+from telegram.utils.types import JSONDict
 
 
-def _render_part(self, name, value):
+def _render_part(self: RequestField, name: str, value: str) -> str:  # pylint: disable=W0613
     """
     Monkey patch urllib3.urllib3.fields.RequestField to make it *not* support RFC2231 compliant
     Content-Disposition headers since telegram servers don't understand it. Instead just escape
     \\ and " and replace any \n and \r with a space.
     """
-    value = value.replace(u'\\', u'\\\\').replace(u'"', u'\\"')
-    value = value.replace(u'\r', u' ').replace(u'\n', u' ')
-    return u'{}="{}"'.format(name, value)
+    value = value.replace('\\', '\\\\').replace('"', '\\"')
+    value = value.replace('\r', ' ').replace('\n', ' ')
+    return f'{name}="{value}"'
 
 
-RequestField._render_part = _render_part
+RequestField._render_part = _render_part  # type: ignore  # pylint: disable=W0212
 
 logging.getLogger('urllib3').setLevel(logging.WARNING)
 
@@ -95,28 +110,34 @@ class Request:
 
     """
 
-    def __init__(self,
-                 con_pool_size=1,
-                 proxy_url=None,
-                 urllib3_proxy_kwargs=None,
-                 connect_timeout=5.,
-                 read_timeout=5.):
+    def __init__(
+        self,
+        con_pool_size: int = 1,
+        proxy_url: str = None,
+        urllib3_proxy_kwargs: JSONDict = None,
+        connect_timeout: float = 5.0,
+        read_timeout: float = 5.0,
+    ):
         if urllib3_proxy_kwargs is None:
             urllib3_proxy_kwargs = dict()
 
         self._connect_timeout = connect_timeout
 
         sockopts = HTTPConnection.default_socket_options + [
-            (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)]
+            (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
+        ]
 
         # TODO: Support other platforms like mac and windows.
         if 'linux' in sys.platform:
-            sockopts.append((socket.IPPROTO_TCP,
-                             socket.TCP_KEEPIDLE, 120))  # pylint: disable=no-member
-            sockopts.append((socket.IPPROTO_TCP,
-                             socket.TCP_KEEPINTVL, 30))  # pylint: disable=no-member
-            sockopts.append((socket.IPPROTO_TCP,
-                             socket.TCP_KEEPCNT, 8))  # pylint: disable=no-member
+            sockopts.append(
+                (socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, 120)  # pylint: disable=no-member
+            )
+            sockopts.append(
+                (socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, 30)  # pylint: disable=no-member
+            )
+            sockopts.append(
+                (socket.IPPROTO_TCP, socket.TCP_KEEPCNT, 8)  # pylint: disable=no-member
+            )
 
         self._con_pool_size = con_pool_size
 
@@ -125,8 +146,8 @@ class Request:
             cert_reqs='CERT_REQUIRED',
             ca_certs=certifi.where(),
             socket_options=sockopts,
-            timeout=urllib3.Timeout(
-                connect=self._connect_timeout, read=read_timeout, total=None))
+            timeout=urllib3.Timeout(connect=self._connect_timeout, read=read_timeout, total=None),
+        )
 
         # Set a proxy according to the following order:
         # * proxy defined in proxy_url (+ urllib3_proxy_kwargs)
@@ -137,20 +158,27 @@ class Request:
         if not proxy_url:
             proxy_url = os.environ.get('HTTPS_PROXY') or os.environ.get('https_proxy')
 
+        self._con_pool: Union[
+            urllib3.PoolManager,
+            appengine.AppEngineManager,
+            'SOCKSProxyManager',  # noqa: F821
+            urllib3.ProxyManager,
+        ] = None  # type: ignore
         if not proxy_url:
             if appengine.is_appengine_sandbox():
                 # Use URLFetch service if running in App Engine
-                mgr = appengine.AppEngineManager()
+                self._con_pool = appengine.AppEngineManager()
             else:
-                mgr = urllib3.PoolManager(**kwargs)
+                self._con_pool = urllib3.PoolManager(**kwargs)
         else:
             kwargs.update(urllib3_proxy_kwargs)
             if proxy_url.startswith('socks'):
                 try:
+                    # pylint: disable=C0415
                     from telegram.vendor.ptb_urllib3.urllib3.contrib.socks import SOCKSProxyManager
-                except ImportError:
-                    raise RuntimeError('PySocks is missing')
-                mgr = SOCKSProxyManager(proxy_url, **kwargs)
+                except ImportError as exc:
+                    raise RuntimeError('PySocks is missing') from exc
+                self._con_pool = SOCKSProxyManager(proxy_url, **kwargs)
             else:
                 mgr = urllib3.proxy_from_url(proxy_url, **kwargs)
                 if mgr.proxy.auth:
@@ -158,18 +186,18 @@ class Request:
                     auth_hdrs = urllib3.make_headers(proxy_basic_auth=mgr.proxy.auth)
                     mgr.proxy_headers.update(auth_hdrs)
 
-        self._con_pool = mgr
+                self._con_pool = mgr
 
     @property
-    def con_pool_size(self):
+    def con_pool_size(self) -> int:
         """The size of the connection pool used."""
         return self._con_pool_size
 
-    def stop(self):
-        self._con_pool.clear()
+    def stop(self) -> None:
+        self._con_pool.clear()  # type: ignore
 
     @staticmethod
-    def _parse(json_data):
+    def _parse(json_data: bytes) -> Union[JSONDict, bool]:
         """Try and parse the JSON returned from Telegram.
 
         Returns:
@@ -180,8 +208,8 @@ class Request:
         decoded_s = json_data.decode('utf-8', 'replace')
         try:
             data = json.loads(decoded_s)
-        except ValueError:
-            raise TelegramError('Invalid server response')
+        except ValueError as exc:
+            raise TelegramError('Invalid server response') from exc
 
         if not data.get('ok'):  # pragma: no cover
             description = data.get('description')
@@ -198,7 +226,7 @@ class Request:
 
         return data['result']
 
-    def _request_wrapper(self, *args, **kwargs):
+    def _request_wrapper(self, *args: object, **kwargs: Any) -> bytes:
         """Wraps urllib3 request for handling known exceptions.
 
         Args:
@@ -206,7 +234,7 @@ class Request:
             kwargs: keyword arguments, passed tp urllib3 request.
 
         Returns:
-            str: A non-parsed JSON text.
+            bytes: A non-parsed JSON text.
 
         Raises:
             TelegramError
@@ -222,47 +250,48 @@ class Request:
 
         try:
             resp = self._con_pool.request(*args, **kwargs)
-        except urllib3.exceptions.TimeoutError:
-            raise TimedOut()
+        except urllib3.exceptions.TimeoutError as error:
+            raise TimedOut() from error
         except urllib3.exceptions.HTTPError as error:
             # HTTPError must come last as its the base urllib3 exception class
             # TODO: do something smart here; for now just raise NetworkError
-            raise NetworkError('urllib3 HTTPError {}'.format(error))
+            raise NetworkError(f'urllib3 HTTPError {error}') from error
 
         if 200 <= resp.status <= 299:
             # 200-299 range are HTTP success statuses
             return resp.data
 
         try:
-            message = self._parse(resp.data)
+            message = str(self._parse(resp.data))
         except ValueError:
             message = 'Unknown HTTPError'
 
         if resp.status in (401, 403):
             raise Unauthorized(message)
-        elif resp.status == 400:
+        if resp.status == 400:
             raise BadRequest(message)
-        elif resp.status == 404:
+        if resp.status == 404:
             raise InvalidToken()
-        elif resp.status == 409:
+        if resp.status == 409:
             raise Conflict(message)
-        elif resp.status == 413:
-            raise NetworkError('File too large. Check telegram api limits '
-                               'https://core.telegram.org/bots/api#senddocument')
-
-        elif resp.status == 502:
+        if resp.status == 413:
+            raise NetworkError(
+                'File too large. Check telegram api limits '
+                'https://core.telegram.org/bots/api#senddocument'
+            )
+        if resp.status == 502:
             raise NetworkError('Bad Gateway')
-        else:
-            raise NetworkError('{} ({})'.format(message, resp.status))
+        raise NetworkError(f'{message} ({resp.status})')
 
-    def get(self, url, timeout=None):
+    def post(self, url: str, data: JSONDict, timeout: float = None) -> Union[JSONDict, bool]:
         """Request an URL.
 
         Args:
             url (:obj:`str`): The web location we want to retrieve.
-            timeout (:obj:`int` | :obj:`float`): If this value is specified, use it as the read
-                timeout from the server (instead of the one specified during creation of the
-                connection pool).
+            data (dict[str, str|int], optional): A dict of key/value pairs.
+            timeout (:obj:`int` | :obj:`float`, optional): If this value is specified, use it as
+                the read timeout from the server (instead of the one specified during creation of
+                the connection pool).
 
         Returns:
           A JSON object.
@@ -273,31 +302,13 @@ class Request:
         if timeout is not None:
             urlopen_kwargs['timeout'] = Timeout(read=timeout, connect=self._connect_timeout)
 
-        result = self._request_wrapper('GET', url, **urlopen_kwargs)
-        return self._parse(result)
-
-    def post(self, url, data, timeout=None):
-        """Request an URL.
-
-        Args:
-            url (:obj:`str`): The web location we want to retrieve.
-            data (dict[str, str|int]): A dict of key/value pairs.
-            timeout (:obj:`int` | :obj:`float`): If this value is specified, use it as the read
-                timeout from the server (instead of the one specified during creation of the
-                connection pool).
-
-        Returns:
-          A JSON object.
-
-        """
-        urlopen_kwargs = {}
-
-        if timeout is not None:
-            urlopen_kwargs['timeout'] = Timeout(read=timeout, connect=self._connect_timeout)
+        if data is None:
+            data = {}
 
         # Are we uploading files?
         files = False
 
+        # pylint: disable=R1702
         for key, val in data.copy().items():
             if isinstance(val, InputFile):
                 # Convert the InputFile to urllib3 field format
@@ -311,30 +322,41 @@ class Request:
                 if isinstance(val, InputMedia):
                     # Attach and set val to attached name
                     data[key] = val.to_json()
-                    if isinstance(val.media, InputFile):
-                        data[val.media.attach] = val.media.field_tuple
+                    if isinstance(val.media, InputFile):  # type: ignore
+                        data[val.media.attach] = val.media.field_tuple  # type: ignore
                 else:
                     # Attach and set val to attached name for all
                     media = []
-                    for m in val:
-                        media.append(m.to_dict())
-                        if isinstance(m.media, InputFile):
-                            data[m.media.attach] = m.media.field_tuple
+                    for med in val:
+                        media_dict = med.to_dict()
+                        media.append(media_dict)
+                        if isinstance(med.media, InputFile):
+                            data[med.media.attach] = med.media.field_tuple
+                            # if the file has a thumb, we also need to attach it to the data
+                            if "thumb" in media_dict:
+                                data[med.thumb.attach] = med.thumb.field_tuple
                     data[key] = json.dumps(media)
                 files = True
+            elif isinstance(val, list):
+                # In case we're sending files, we need to json-dump lists manually
+                # As we can't know if that's the case, we just json-dump here
+                data[key] = json.dumps(val)
 
         # Use multipart upload if we're uploading files, otherwise use JSON
         if files:
             result = self._request_wrapper('POST', url, fields=data, **urlopen_kwargs)
         else:
-            result = self._request_wrapper('POST', url,
-                                           body=json.dumps(data).encode('utf-8'),
-                                           headers={'Content-Type': 'application/json'},
-                                           **urlopen_kwargs)
+            result = self._request_wrapper(
+                'POST',
+                url,
+                body=json.dumps(data).encode('utf-8'),
+                headers={'Content-Type': 'application/json'},
+                **urlopen_kwargs,
+            )
 
         return self._parse(result)
 
-    def retrieve(self, url, timeout=None):
+    def retrieve(self, url: str, timeout: float = None) -> bytes:
         """Retrieve the contents of a file by its URL.
 
         Args:
@@ -350,7 +372,7 @@ class Request:
 
         return self._request_wrapper('GET', url, **urlopen_kwargs)
 
-    def download(self, url, filename, timeout=None):
+    def download(self, url: str, filename: str, timeout: float = None) -> None:
         """Download a file by its URL.
 
         Args:
@@ -358,9 +380,7 @@ class Request:
             timeout (:obj:`int` | :obj:`float`): If this value is specified, use it as the read
                 timeout from the server (instead of the one specified during creation of the
                 connection pool).
-
-          filename:
-            The filename within the path to download the file.
+            filename (:obj:`str`): The filename within the path to download the file.
 
         """
         buf = self.retrieve(url, timeout=timeout)
