@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -49,30 +49,34 @@ class TestChatMember:
         time = datetime.datetime.utcnow()
         custom_title = 'custom_title'
 
-        json_dict = {'user': user.to_dict(),
-                     'status': self.status,
-                     'custom_title': custom_title,
-                     'until_date': to_timestamp(time),
-                     'can_be_edited': False,
-                     'can_change_info': True,
-                     'can_post_messages': False,
-                     'can_edit_messages': True,
-                     'can_delete_messages': True,
-                     'can_invite_users': False,
-                     'can_restrict_members': True,
-                     'can_pin_messages': False,
-                     'can_promote_members': True,
-                     'can_send_messages': False,
-                     'can_send_media_messages': True,
-                     'can_send_polls': False,
-                     'can_send_other_messages': True,
-                     'can_add_web_page_previews': False}
+        json_dict = {
+            'user': user.to_dict(),
+            'status': self.status,
+            'custom_title': custom_title,
+            'is_anonymous': True,
+            'until_date': to_timestamp(time),
+            'can_be_edited': False,
+            'can_change_info': True,
+            'can_post_messages': False,
+            'can_edit_messages': True,
+            'can_delete_messages': True,
+            'can_invite_users': False,
+            'can_restrict_members': True,
+            'can_pin_messages': False,
+            'can_promote_members': True,
+            'can_send_messages': False,
+            'can_send_media_messages': True,
+            'can_send_polls': False,
+            'can_send_other_messages': True,
+            'can_add_web_page_previews': False,
+        }
 
         chat_member = ChatMember.de_json(json_dict, bot)
 
         assert chat_member.user == user
         assert chat_member.status == self.status
         assert chat_member.custom_title == custom_title
+        assert chat_member.is_anonymous is True
         assert chat_member.can_be_edited is False
         assert chat_member.can_change_info is True
         assert chat_member.can_post_messages is False
