@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2020
+# Copyright (C) 2020-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -29,14 +29,22 @@ class TestDefault:
 
         with pytest.raises(AttributeError):
             defaults.parse_mode = True
+        with pytest.raises(AttributeError):
+            defaults.explanation_parse_mode = True
         with pytest.raises(AttributeError):
             defaults.disable_notification = True
         with pytest.raises(AttributeError):
             defaults.disable_web_page_preview = True
+        with pytest.raises(AttributeError):
+            defaults.allow_sending_without_reply = True
         with pytest.raises(AttributeError):
             defaults.timeout = True
         with pytest.raises(AttributeError):
             defaults.quote = True
+        with pytest.raises(AttributeError):
+            defaults.tzinfo = True
+        with pytest.raises(AttributeError):
+            defaults.run_async = True
 
     def test_equality(self):
         a = Defaults(parse_mode='HTML', quote=True)
