@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,6 +16,7 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
+import logging
 from queue import Queue
 from threading import current_thread
 from time import sleep
@@ -23,23 +24,31 @@ from time import sleep
 import pytest
 
 from telegram import TelegramError, Message, User, Chat, Update, Bot, MessageEntity
-from telegram.ext import (MessageHandler, Filters, CommandHandler, CallbackContext,
-                          JobQueue, BasePersistence)
+from telegram.ext import (
+    MessageHandler,
+    Filters,
+    Defaults,
+    CommandHandler,
+    CallbackContext,
+    JobQueue,
+    BasePersistence,
+)
 from telegram.ext.dispatcher import run_async, Dispatcher, DispatcherHandlerStop
 from telegram.utils.deprecate import TelegramDeprecationWarning
+from telegram.utils.helpers import DEFAULT_FALSE
 from tests.conftest import create_dp
 from collections import defaultdict
 
 
 @pytest.fixture(scope='function')
 def dp2(bot):
-    for dp in create_dp(bot):
-        yield dp
+    yield from create_dp(bot)
 
 
 class TestDispatcher:
-    message_update = Update(1,
-                            message=Message(1, User(1, '', False), None, Chat(1, ''), text='Text'))
+    message_update = Update(
+        1, message=Message(1, None, Chat(1, ''), from_user=User(1, '', False), text='Text')
+    )
     received = None
     count = 0
 
@@ -54,6 +63,9 @@ class TestDispatcher:
     def error_handler(self, bot, update, error):
         self.received = error.message
 
+    def error_handler_context(self, update, context):
+        self.received = context.error.message
+
     def error_handler_raise_error(self, bot, update, error):
         raise Exception('Failing bigly')
 
@@ -67,18 +79,22 @@ class TestDispatcher:
         return callback
 
     def callback_raise_error(self, bot, update):
-        raise TelegramError(update.message.text)
+        if isinstance(bot, Bot):
+            raise TelegramError(update.message.text)
+        raise TelegramError(bot.message.text)
 
     def callback_if_not_update_queue(self, bot, update, update_queue=None):
         if update_queue is not None:
             self.received = update.message
 
     def callback_context(self, update, context):
-        if (isinstance(context, CallbackContext)
-                and isinstance(context.bot, Bot)
-                and isinstance(context.update_queue, Queue)
-                and isinstance(context.job_queue, JobQueue)
-                and isinstance(context.error, TelegramError)):
+        if (
+            isinstance(context, CallbackContext)
+            and isinstance(context.bot, Bot)
+            and isinstance(context.update_queue, Queue)
+            and isinstance(context.job_queue, JobQueue)
+            and isinstance(context.error, TelegramError)
+        ):
             self.received = context.error.message
 
     def test_one_context_per_update(self, cdp):
@@ -105,7 +121,7 @@ class TestDispatcher:
         dp.add_error_handler(self.error_handler)
         error = TelegramError('Unauthorized.')
         dp.update_queue.put(error)
-        sleep(.1)
+        sleep(0.1)
         assert self.received == 'Unauthorized.'
 
         # Remove handler
@@ -113,9 +129,16 @@ class TestDispatcher:
         self.reset()
 
         dp.update_queue.put(error)
-        sleep(.1)
+        sleep(0.1)
         assert self.received is None
 
+    def test_double_add_error_handler(self, dp, caplog):
+        dp.add_error_handler(self.error_handler)
+        with caplog.at_level(logging.DEBUG):
+            dp.add_error_handler(self.error_handler)
+            assert len(caplog.records) == 1
+            assert caplog.records[-1].getMessage().startswith('The callback is already registered')
+
     def test_construction_with_bad_persistence(self, caplog, bot):
         class my_per:
             def __init__(self):
@@ -123,8 +146,9 @@ class TestDispatcher:
                 self.store_chat_data = False
                 self.store_bot_data = False
 
-        with pytest.raises(TypeError,
-                           match='persistence should be based on telegram.ext.BasePersistence'):
+        with pytest.raises(
+            TypeError, match='persistence must be based on telegram.ext.BasePersistence'
+        ):
             Dispatcher(bot, None, persistence=my_per())
 
     def test_error_handler_that_raises_errors(self, dp):
@@ -140,17 +164,56 @@ class TestDispatcher:
         # From errors caused by handlers
         dp.add_handler(handler_raise_error)
         dp.update_queue.put(self.message_update)
-        sleep(.1)
+        sleep(0.1)
 
         # From errors in the update_queue
         dp.remove_handler(handler_raise_error)
         dp.add_handler(handler_increase_count)
         dp.update_queue.put(error)
         dp.update_queue.put(self.message_update)
-        sleep(.1)
+        sleep(0.1)
 
         assert self.count == 1
 
+    @pytest.mark.parametrize(['run_async', 'expected_output'], [(True, 5), (False, 0)])
+    def test_default_run_async_error_handler(self, dp, monkeypatch, run_async, expected_output):
+        def mock_async_err_handler(*args, **kwargs):
+            self.count = 5
+
+        # set defaults value to dp.bot
+        dp.bot.defaults = Defaults(run_async=run_async)
+        try:
+            dp.add_handler(MessageHandler(Filters.all, self.callback_raise_error))
+            dp.add_error_handler(self.error_handler)
+
+            monkeypatch.setattr(dp, 'run_async', mock_async_err_handler)
+            dp.process_update(self.message_update)
+
+            assert self.count == expected_output
+
+        finally:
+            # reset dp.bot.defaults values
+            dp.bot.defaults = None
+
+    @pytest.mark.parametrize(
+        ['run_async', 'expected_output'], [(True, 'running async'), (False, None)]
+    )
+    def test_default_run_async(self, monkeypatch, dp, run_async, expected_output):
+        def mock_run_async(*args, **kwargs):
+            self.received = 'running async'
+
+        # set defaults value to dp.bot
+        dp.bot.defaults = Defaults(run_async=run_async)
+        try:
+            dp.add_handler(MessageHandler(Filters.all, lambda u, c: None))
+            monkeypatch.setattr(dp, 'run_async', mock_run_async)
+            dp.process_update(self.message_update)
+            assert self.received == expected_output
+
+        finally:
+            # reset defaults value
+            dp.bot.defaults = None
+
     def test_run_async_multiple(self, bot, dp, dp2):
         def get_dispatcher_name(q):
             q.put(current_thread().name)
@@ -161,7 +224,7 @@ class TestDispatcher:
         dp.run_async(get_dispatcher_name, q1)
         dp2.run_async(get_dispatcher_name, q2)
 
-        sleep(.1)
+        sleep(0.1)
 
         name1 = q1.get()
         name2 = q2.get()
@@ -182,27 +245,151 @@ class TestDispatcher:
             must_raise_runtime_error()
 
     def test_run_async_with_args(self, dp):
-        dp.add_handler(MessageHandler(Filters.all,
-                                      run_async(self.callback_if_not_update_queue),
-                                      pass_update_queue=True))
+        dp.add_handler(
+            MessageHandler(
+                Filters.all, run_async(self.callback_if_not_update_queue), pass_update_queue=True
+            )
+        )
 
         dp.update_queue.put(self.message_update)
-        sleep(.1)
+        sleep(0.1)
         assert self.received == self.message_update.message
 
+    def test_multiple_run_async_deprecation(self, dp):
+        assert isinstance(dp, Dispatcher)
+
+        @run_async
+        def callback(update, context):
+            pass
+
+        dp.add_handler(MessageHandler(Filters.all, callback))
+
+        with pytest.warns(TelegramDeprecationWarning, match='@run_async decorator'):
+            dp.process_update(self.message_update)
+
+    def test_async_raises_dispatcher_handler_stop(self, dp, caplog):
+        @run_async
+        def callback(update, context):
+            raise DispatcherHandlerStop()
+
+        dp.add_handler(MessageHandler(Filters.all, callback))
+
+        with caplog.at_level(logging.WARNING):
+            dp.update_queue.put(self.message_update)
+            sleep(0.1)
+            assert len(caplog.records) == 1
+            assert (
+                caplog.records[-1]
+                .getMessage()
+                .startswith('DispatcherHandlerStop is not supported ' 'with async functions')
+            )
+
+    def test_async_raises_exception(self, dp, caplog):
+        @run_async
+        def callback(update, context):
+            raise RuntimeError('async raising exception')
+
+        dp.add_handler(MessageHandler(Filters.all, callback))
+
+        with caplog.at_level(logging.WARNING):
+            dp.update_queue.put(self.message_update)
+            sleep(0.1)
+            assert len(caplog.records) == 1
+            assert (
+                caplog.records[-1]
+                .getMessage()
+                .startswith('A promise with deactivated error handling')
+            )
+
+    def test_add_async_handler(self, dp):
+        dp.add_handler(
+            MessageHandler(
+                Filters.all,
+                self.callback_if_not_update_queue,
+                pass_update_queue=True,
+                run_async=True,
+            )
+        )
+
+        dp.update_queue.put(self.message_update)
+        sleep(0.1)
+        assert self.received == self.message_update.message
+
+    def test_run_async_no_error_handler(self, dp, caplog):
+        def func():
+            raise RuntimeError('Async Error')
+
+        with caplog.at_level(logging.ERROR):
+            dp.run_async(func)
+            sleep(0.1)
+            assert len(caplog.records) == 1
+            assert caplog.records[-1].getMessage().startswith('No error handlers are registered')
+
+    def test_async_handler_error_handler(self, dp):
+        dp.add_handler(MessageHandler(Filters.all, self.callback_raise_error, run_async=True))
+        dp.add_error_handler(self.error_handler)
+
+        dp.update_queue.put(self.message_update)
+        sleep(0.1)
+        assert self.received == self.message_update.message.text
+
+    def test_async_handler_async_error_handler_context(self, cdp):
+        cdp.add_handler(MessageHandler(Filters.all, self.callback_raise_error, run_async=True))
+        cdp.add_error_handler(self.error_handler_context, run_async=True)
+
+        cdp.update_queue.put(self.message_update)
+        sleep(2)
+        assert self.received == self.message_update.message.text
+
+    def test_async_handler_error_handler_that_raises_error(self, dp, caplog):
+        handler = MessageHandler(Filters.all, self.callback_raise_error, run_async=True)
+        dp.add_handler(handler)
+        dp.add_error_handler(self.error_handler_raise_error, run_async=False)
+
+        with caplog.at_level(logging.ERROR):
+            dp.update_queue.put(self.message_update)
+            sleep(0.1)
+            assert len(caplog.records) == 1
+            assert caplog.records[-1].getMessage().startswith('An uncaught error was raised')
+
+        # Make sure that the main loop still runs
+        dp.remove_handler(handler)
+        dp.add_handler(MessageHandler(Filters.all, self.callback_increase_count, run_async=True))
+        dp.update_queue.put(self.message_update)
+        sleep(0.1)
+        assert self.count == 1
+
+    def test_async_handler_async_error_handler_that_raises_error(self, dp, caplog):
+        handler = MessageHandler(Filters.all, self.callback_raise_error, run_async=True)
+        dp.add_handler(handler)
+        dp.add_error_handler(self.error_handler_raise_error, run_async=True)
+
+        with caplog.at_level(logging.ERROR):
+            dp.update_queue.put(self.message_update)
+            sleep(0.1)
+            assert len(caplog.records) == 1
+            assert caplog.records[-1].getMessage().startswith('An uncaught error was raised')
+
+        # Make sure that the main loop still runs
+        dp.remove_handler(handler)
+        dp.add_handler(MessageHandler(Filters.all, self.callback_increase_count, run_async=True))
+        dp.update_queue.put(self.message_update)
+        sleep(0.1)
+        assert self.count == 1
+
     def test_error_in_handler(self, dp):
         dp.add_handler(MessageHandler(Filters.all, self.callback_raise_error))
         dp.add_error_handler(self.error_handler)
 
         dp.update_queue.put(self.message_update)
-        sleep(.1)
+        sleep(0.1)
         assert self.received == self.message_update.message.text
 
     def test_add_remove_handler(self, dp):
         handler = MessageHandler(Filters.all, self.callback_increase_count)
         dp.add_handler(handler)
         dp.update_queue.put(self.message_update)
-        sleep(.1)
+        sleep(0.1)
         assert self.count == 1
         dp.remove_handler(handler)
         dp.update_queue.put(self.message_update)
@@ -224,7 +411,7 @@ class TestDispatcher:
         dp.add_handler(MessageHandler(Filters.all, self.callback_set_count(2)))
         dp.add_handler(MessageHandler(Filters.text, self.callback_set_count(3)))
         dp.update_queue.put(self.message_update)
-        sleep(.1)
+        sleep(0.1)
         assert self.count == 2
 
     def test_groups(self, dp):
@@ -233,7 +420,7 @@ class TestDispatcher:
         dp.add_handler(MessageHandler(Filters.all, self.callback_increase_count), group=-1)
 
         dp.update_queue.put(self.message_update)
-        sleep(.1)
+        sleep(0.1)
         assert self.count == 3
 
     def test_add_handler_errors(self, dp):
@@ -262,11 +449,20 @@ class TestDispatcher:
             passed.append('error')
             passed.append(e)
 
-        update = Update(1, message=Message(1, None, None, None, text='/start',
-                                           entities=[MessageEntity(type=MessageEntity.BOT_COMMAND,
-                                                                   offset=0,
-                                                                   length=len('/start'))],
-                                           bot=bot))
+        update = Update(
+            1,
+            message=Message(
+                1,
+                None,
+                None,
+                None,
+                text='/start',
+                entities=[
+                    MessageEntity(type=MessageEntity.BOT_COMMAND, offset=0, length=len('/start'))
+                ],
+                bot=bot,
+            ),
+        )
 
         # If Stop raised handlers in other groups should not be called.
         passed = []
@@ -294,11 +490,20 @@ class TestDispatcher:
             passed.append('error')
             passed.append(e)
 
-        update = Update(1, message=Message(1, None, None, None, text='/start',
-                                           entities=[MessageEntity(type=MessageEntity.BOT_COMMAND,
-                                                                   offset=0,
-                                                                   length=len('/start'))],
-                                           bot=bot))
+        update = Update(
+            1,
+            message=Message(
+                1,
+                None,
+                None,
+                None,
+                text='/start',
+                entities=[
+                    MessageEntity(type=MessageEntity.BOT_COMMAND, offset=0, length=len('/start'))
+                ],
+                bot=bot,
+            ),
+        )
 
         # If an unhandled exception was caught, no further handlers from the same group should be
         # called. Also, the error handler should be called and receive the exception
@@ -328,11 +533,20 @@ class TestDispatcher:
             passed.append('error')
             passed.append(e)
 
-        update = Update(1, message=Message(1, None, None, None, text='/start',
-                                           entities=[MessageEntity(type=MessageEntity.BOT_COMMAND,
-                                                                   offset=0,
-                                                                   length=len('/start'))],
-                                           bot=bot))
+        update = Update(
+            1,
+            message=Message(
+                1,
+                None,
+                None,
+                None,
+                text='/start',
+                entities=[
+                    MessageEntity(type=MessageEntity.BOT_COMMAND, offset=0, length=len('/start'))
+                ],
+                bot=bot,
+            ),
+        )
 
         # If a TelegramException was caught, an error handler should be called and no further
         # handlers from the same group should be called.
@@ -344,7 +558,7 @@ class TestDispatcher:
         assert passed == ['start1', 'error', err, 'start3']
         assert passed[2] is err
 
-    def test_error_while_saving_chat_data(self, dp, bot):
+    def test_error_while_saving_chat_data(self, bot):
         increment = []
 
         class OwnPersistence(BasePersistence):
@@ -387,14 +601,22 @@ class TestDispatcher:
         # If updating a user_data or chat_data from a persistence object throws an error,
         # the error handler should catch it
 
-        update = Update(1, message=Message(1, User(1, "Test", False), None, Chat(1, "lala"),
-                                           text='/start',
-                                           entities=[MessageEntity(type=MessageEntity.BOT_COMMAND,
-                                                                   offset=0,
-                                                                   length=len('/start'))],
-                                           bot=bot))
+        update = Update(
+            1,
+            message=Message(
+                1,
+                None,
+                Chat(1, "lala"),
+                from_user=User(1, "Test", False),
+                text='/start',
+                entities=[
+                    MessageEntity(type=MessageEntity.BOT_COMMAND, offset=0, length=len('/start'))
+                ],
+                bot=bot,
+            ),
+        )
         my_persistence = OwnPersistence()
-        dp = Dispatcher(bot, None, persistence=my_persistence)
+        dp = Dispatcher(bot, None, persistence=my_persistence, use_context=False)
         dp.add_handler(CommandHandler('start', start1))
         dp.add_error_handler(error)
         dp.process_update(update)
@@ -419,11 +641,20 @@ class TestDispatcher:
             passed.append(e)
             raise DispatcherHandlerStop
 
-        update = Update(1, message=Message(1, None, None, None, text='/start',
-                                           entities=[MessageEntity(type=MessageEntity.BOT_COMMAND,
-                                                                   offset=0,
-                                                                   length=len('/start'))],
-                                           bot=bot))
+        update = Update(
+            1,
+            message=Message(
+                1,
+                None,
+                None,
+                None,
+                text='/start',
+                entities=[
+                    MessageEntity(type=MessageEntity.BOT_COMMAND, offset=0, length=len('/start'))
+                ],
+                bot=bot,
+            ),
+        )
 
         # If a TelegramException was caught, an error handler should be called and no further
         # handlers from the same group should be called.
@@ -440,24 +671,25 @@ class TestDispatcher:
 
         error = TelegramError('Unauthorized.')
         cdp.update_queue.put(error)
-        sleep(.1)
+        sleep(0.1)
         assert self.received == 'Unauthorized.'
 
     def test_sensible_worker_thread_names(self, dp2):
         thread_names = [thread.name for thread in getattr(dp2, '_Dispatcher__async_threads')]
         print(thread_names)
         for thread_name in thread_names:
-            assert thread_name.startswith("Bot:{}:worker:".format(dp2.bot.id))
+            assert thread_name.startswith(f"Bot:{dp2.bot.id}:worker:")
 
     def test_non_context_deprecation(self, dp):
         with pytest.warns(TelegramDeprecationWarning):
-            Dispatcher(dp.bot, dp.update_queue, job_queue=dp.job_queue, workers=0,
-                       use_context=False)
+            Dispatcher(
+                dp.bot, dp.update_queue, job_queue=dp.job_queue, workers=0, use_context=False
+            )
 
     def test_error_while_persisting(self, cdp, monkeypatch):
         class OwnPersistence(BasePersistence):
             def __init__(self):
-                super(OwnPersistence, self).__init__()
+                super().__init__()
                 self.store_user_data = True
                 self.store_chat_data = True
                 self.store_bot_data = True
@@ -502,7 +734,9 @@ class TestDispatcher:
         def logger(message):
             assert 'uncaught error was raised while handling' in message
 
-        update = Update(1, message=Message(1, User(1, '', False), None, Chat(1, ''), text='Text'))
+        update = Update(
+            1, message=Message(1, None, Chat(1, ''), from_user=User(1, '', False), text='Text')
+        )
         handler = MessageHandler(Filters.all, callback)
         cdp.add_handler(handler)
         cdp.add_error_handler(error)
@@ -515,7 +749,7 @@ class TestDispatcher:
     def test_persisting_no_user_no_chat(self, cdp):
         class OwnPersistence(BasePersistence):
             def __init__(self):
-                super(OwnPersistence, self).__init__()
+                super().__init__()
                 self.store_user_data = True
                 self.store_chat_data = True
                 self.store_bot_data = True
@@ -554,7 +788,9 @@ class TestDispatcher:
         cdp.add_handler(handler)
         cdp.persistence = OwnPersistence()
 
-        update = Update(1, message=Message(1, User(1, '', False), None, None, text='Text'))
+        update = Update(
+            1, message=Message(1, None, None, from_user=User(1, '', False), text='Text')
+        )
         cdp.process_update(update)
         assert cdp.persistence.test_flag_bot_data
         assert cdp.persistence.test_flag_user_data
@@ -563,8 +799,101 @@ class TestDispatcher:
         cdp.persistence.test_flag_bot_data = False
         cdp.persistence.test_flag_user_data = False
         cdp.persistence.test_flag_chat_data = False
-        update = Update(1, message=Message(1, None, None, Chat(1, ''), text='Text'))
+        update = Update(1, message=Message(1, None, Chat(1, ''), from_user=None, text='Text'))
         cdp.process_update(update)
         assert cdp.persistence.test_flag_bot_data
         assert not cdp.persistence.test_flag_user_data
         assert cdp.persistence.test_flag_chat_data
+
+    def test_update_persistence_once_per_update(self, monkeypatch, dp):
+        def update_persistence(*args, **kwargs):
+            self.count += 1
+
+        def dummy_callback(*args):
+            pass
+
+        monkeypatch.setattr(dp, 'update_persistence', update_persistence)
+
+        for group in range(5):
+            dp.add_handler(MessageHandler(Filters.text, dummy_callback), group=group)
+
+        update = Update(1, message=Message(1, None, Chat(1, ''), from_user=None, text=None))
+        dp.process_update(update)
+        assert self.count == 0
+
+        update = Update(1, message=Message(1, None, Chat(1, ''), from_user=None, text='text'))
+        dp.process_update(update)
+        assert self.count == 1
+
+    def test_update_persistence_all_async(self, monkeypatch, dp):
+        def update_persistence(*args, **kwargs):
+            self.count += 1
+
+        def dummy_callback(*args, **kwargs):
+            pass
+
+        monkeypatch.setattr(dp, 'update_persistence', update_persistence)
+        monkeypatch.setattr(dp, 'run_async', dummy_callback)
+
+        for group in range(5):
+            dp.add_handler(
+                MessageHandler(Filters.text, dummy_callback, run_async=True), group=group
+            )
+
+        update = Update(1, message=Message(1, None, Chat(1, ''), from_user=None, text='Text'))
+        dp.process_update(update)
+        assert self.count == 0
+
+        dp.bot.defaults = Defaults(run_async=True)
+        try:
+            for group in range(5):
+                dp.add_handler(MessageHandler(Filters.text, dummy_callback), group=group)
+
+            update = Update(1, message=Message(1, None, Chat(1, ''), from_user=None, text='Text'))
+            dp.process_update(update)
+            assert self.count == 0
+        finally:
+            dp.bot.defaults = None
+
+    @pytest.mark.parametrize('run_async', [DEFAULT_FALSE, False])
+    def test_update_persistence_one_sync(self, monkeypatch, dp, run_async):
+        def update_persistence(*args, **kwargs):
+            self.count += 1
+
+        def dummy_callback(*args, **kwargs):
+            pass
+
+        monkeypatch.setattr(dp, 'update_persistence', update_persistence)
+        monkeypatch.setattr(dp, 'run_async', dummy_callback)
+
+        for group in range(5):
+            dp.add_handler(
+                MessageHandler(Filters.text, dummy_callback, run_async=True), group=group
+            )
+        dp.add_handler(MessageHandler(Filters.text, dummy_callback, run_async=run_async), group=5)
+
+        update = Update(1, message=Message(1, None, Chat(1, ''), from_user=None, text='Text'))
+        dp.process_update(update)
+        assert self.count == 1
+
+    @pytest.mark.parametrize('run_async,expected', [(DEFAULT_FALSE, 1), (False, 1), (True, 0)])
+    def test_update_persistence_defaults_async(self, monkeypatch, dp, run_async, expected):
+        def update_persistence(*args, **kwargs):
+            self.count += 1
+
+        def dummy_callback(*args, **kwargs):
+            pass
+
+        monkeypatch.setattr(dp, 'update_persistence', update_persistence)
+        monkeypatch.setattr(dp, 'run_async', dummy_callback)
+        dp.bot.defaults = Defaults(run_async=run_async)
+
+        try:
+            for group in range(5):
+                dp.add_handler(MessageHandler(Filters.text, dummy_callback), group=group)
+
+            update = Update(1, message=Message(1, None, Chat(1, ''), from_user=None, text='Text'))
+            dp.process_update(update)
+            assert self.count == expected
+        finally:
+            dp.bot.defaults = None
