@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -24,9 +24,9 @@ from telegram import GameHighScore, User
 
 @pytest.fixture(scope='class')
 def game_highscore():
-    return GameHighScore(TestGameHighScore.position,
-                         TestGameHighScore.user,
-                         TestGameHighScore.score)
+    return GameHighScore(
+        TestGameHighScore.position, TestGameHighScore.user, TestGameHighScore.score
+    )
 
 
 class TestGameHighScore:
@@ -35,9 +35,7 @@ class TestGameHighScore:
     score = 42
 
     def test_de_json(self, bot):
-        json_dict = {'position': self.position,
-                     'user': self.user.to_dict(),
-                     'score': self.score}
+        json_dict = {'position': self.position, 'user': self.user.to_dict(), 'score': self.score}
         highscore = GameHighScore.de_json(json_dict, bot)
 
         assert highscore.position == self.position
@@ -51,3 +49,22 @@ class TestGameHighScore:
         assert game_highscore_dict['position'] == game_highscore.position
         assert game_highscore_dict['user'] == game_highscore.user.to_dict()
         assert game_highscore_dict['score'] == game_highscore.score
+
+    def test_equality(self):
+        a = GameHighScore(1, User(2, 'test user', False), 42)
+        b = GameHighScore(1, User(2, 'test user', False), 42)
+        c = GameHighScore(2, User(2, 'test user', False), 42)
+        d = GameHighScore(1, User(3, 'test user', False), 42)
+        e = User(3, 'test user', False)
+
+        assert a == b
+        assert hash(a) == hash(b)
+
+        assert a != c
+        assert hash(a) != hash(c)
+
+        assert a != d
+        assert hash(a) != hash(d)
+
+        assert a != e
+        assert hash(a) != hash(e)
