@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,13 +19,20 @@
 
 import pytest
 
-from telegram import User, Location, InlineQuery, Update
+from telegram import User, Location, InlineQuery, Update, Bot
+from tests.conftest import check_shortcut_signature, check_shortcut_call, check_defaults_handling
 
 
 @pytest.fixture(scope='class')
 def inline_query(bot):
-    return InlineQuery(TestInlineQuery.id_, TestInlineQuery.from_user, TestInlineQuery.query,
-                       TestInlineQuery.offset, location=TestInlineQuery.location, bot=bot)
+    return InlineQuery(
+        TestInlineQuery.id_,
+        TestInlineQuery.from_user,
+        TestInlineQuery.query,
+        TestInlineQuery.offset,
+        location=TestInlineQuery.location,
+        bot=bot,
+    )
 
 
 class TestInlineQuery:
@@ -41,7 +48,7 @@ class TestInlineQuery:
             'from': self.from_user.to_dict(),
             'query': self.query,
             'offset': self.offset,
-            'location': self.location.to_dict()
+            'location': self.location.to_dict(),
         }
         inline_query_json = InlineQuery.de_json(json_dict, bot)
 
@@ -62,11 +69,30 @@ class TestInlineQuery:
         assert inline_query_dict['offset'] == inline_query.offset
 
     def test_answer(self, monkeypatch, inline_query):
-        def test(*args, **kwargs):
-            return args[0] == inline_query.id
+        def make_assertion(*_, **kwargs):
+            return kwargs['inline_query_id'] == inline_query.id
 
-        monkeypatch.setattr(inline_query.bot, 'answer_inline_query', test)
-        assert inline_query.answer()
+        assert check_shortcut_signature(
+            InlineQuery.answer, Bot.answer_inline_query, ['inline_query_id'], ['auto_pagination']
+        )
+        assert check_shortcut_call(inline_query.answer, inline_query.bot, 'answer_inline_query')
+        assert check_defaults_handling(inline_query.answer, inline_query.bot)
+
+        monkeypatch.setattr(inline_query.bot, 'answer_inline_query', make_assertion)
+        assert inline_query.answer(results=[])
+
+    def test_answer_error(self, inline_query):
+        with pytest.raises(TypeError, match='mutually exclusive'):
+            inline_query.answer(results=[], auto_pagination=True, current_offset='foobar')
+
+    def test_answer_auto_pagination(self, monkeypatch, inline_query):
+        def make_assertion(*_, **kwargs):
+            inline_query_id_matches = kwargs['inline_query_id'] == inline_query.id
+            offset_matches = kwargs.get('current_offset') == inline_query.offset
+            return offset_matches and inline_query_id_matches
+
+        monkeypatch.setattr(inline_query.bot, 'answer_inline_query', make_assertion)
+        assert inline_query.answer(results=[], auto_pagination=True)
 
     def test_equality(self):
         a = InlineQuery(self.id_, User(1, '', False), '', '')
