@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -22,11 +22,21 @@ from queue import Queue
 import pytest
 from telegram.utils.deprecate import TelegramDeprecationWarning
 
-from telegram import (Message, Update, Chat, Bot, User, CallbackQuery, InlineQuery,
-                      ChosenInlineResult, ShippingQuery, PreCheckoutQuery)
-from telegram.ext import Filters, MessageHandler, CallbackContext, JobQueue
+from telegram import (
+    Message,
+    Update,
+    Chat,
+    Bot,
+    User,
+    CallbackQuery,
+    InlineQuery,
+    ChosenInlineResult,
+    ShippingQuery,
+    PreCheckoutQuery,
+)
+from telegram.ext import Filters, MessageHandler, CallbackContext, JobQueue, UpdateFilter
 
-message = Message(1, User(1, '', False), None, Chat(1, ''), text='Text')
+message = Message(1, None, Chat(1, ''), from_user=User(1, '', False), text='Text')
 
 params = [
     {'callback_query': CallbackQuery(1, User(1, '', False), 'chat', message=message)},
@@ -34,11 +44,17 @@ params = [
     {'chosen_inline_result': ChosenInlineResult('id', User(1, '', False), '')},
     {'shipping_query': ShippingQuery('id', User(1, '', False), '', None)},
     {'pre_checkout_query': PreCheckoutQuery('id', User(1, '', False), '', 0, '')},
-    {'callback_query': CallbackQuery(1, User(1, '', False), 'chat')}
+    {'callback_query': CallbackQuery(1, User(1, '', False), 'chat')},
 ]
 
-ids = ('callback_query', 'inline_query', 'chosen_inline_result',
-       'shipping_query', 'pre_checkout_query', 'callback_query_without_message')
+ids = (
+    'callback_query',
+    'inline_query',
+    'chosen_inline_result',
+    'shipping_query',
+    'pre_checkout_query',
+    'callback_query_without_message',
+)
 
 
 @pytest.fixture(scope='class', params=params, ids=ids)
@@ -48,7 +64,7 @@ def false_update(request):
 
 @pytest.fixture(scope='class')
 def message(bot):
-    return Message(1, User(1, '', False), None, Chat(1, ''), bot=bot)
+    return Message(1, None, Chat(1, ''), from_user=User(1, '', False), bot=bot)
 
 
 class TestMessageHandler:
@@ -77,20 +93,31 @@ class TestMessageHandler:
         self.test_flag = (job_queue is not None) and (update_queue is not None)
 
     def callback_context(self, update, context):
-        self.test_flag = (isinstance(context, CallbackContext)
-                          and isinstance(context.bot, Bot)
-                          and isinstance(update, Update)
-                          and isinstance(context.update_queue, Queue)
-                          and isinstance(context.job_queue, JobQueue)
-                          and isinstance(context.chat_data, dict)
-                          and isinstance(context.bot_data, dict)
-                          and ((isinstance(context.user_data, dict)
-                                and (isinstance(update.message, Message)
-                                     or isinstance(update.edited_message, Message)))
-                               or (context.user_data is None
-                                   and (isinstance(update.channel_post, Message)
-                                        or isinstance(update.edited_channel_post, Message)))
-                               ))
+        self.test_flag = (
+            isinstance(context, CallbackContext)
+            and isinstance(context.bot, Bot)
+            and isinstance(update, Update)
+            and isinstance(context.update_queue, Queue)
+            and isinstance(context.job_queue, JobQueue)
+            and isinstance(context.chat_data, dict)
+            and isinstance(context.bot_data, dict)
+            and (
+                (
+                    isinstance(context.user_data, dict)
+                    and (
+                        isinstance(update.message, Message)
+                        or isinstance(update.edited_message, Message)
+                    )
+                )
+                or (
+                    context.user_data is None
+                    and (
+                        isinstance(update.channel_post, Message)
+                        or isinstance(update.edited_channel_post, Message)
+                    )
+                )
+            )
+        )
 
     def callback_context_regex1(self, update, context):
         if context.matches:
@@ -121,8 +148,13 @@ class TestMessageHandler:
             MessageHandler(None, self.callback_basic, channel_post_updates=True)
 
     def test_edited_deprecated(self, message):
-        handler = MessageHandler(None, self.callback_basic, edited_updates=True,
-                                 message_updates=False, channel_post_updates=False)
+        handler = MessageHandler(
+            None,
+            self.callback_basic,
+            edited_updates=True,
+            message_updates=False,
+            channel_post_updates=False,
+        )
 
         assert handler.check_update(Update(0, edited_message=message))
         assert not handler.check_update(Update(0, message=message))
@@ -130,17 +162,26 @@ class TestMessageHandler:
         assert handler.check_update(Update(0, edited_channel_post=message))
 
     def test_channel_post_deprecated(self, message):
-        handler = MessageHandler(None, self.callback_basic,
-                                 edited_updates=False, message_updates=False,
-                                 channel_post_updates=True)
+        handler = MessageHandler(
+            None,
+            self.callback_basic,
+            edited_updates=False,
+            message_updates=False,
+            channel_post_updates=True,
+        )
         assert not handler.check_update(Update(0, edited_message=message))
         assert not handler.check_update(Update(0, message=message))
         assert handler.check_update(Update(0, channel_post=message))
         assert not handler.check_update(Update(0, edited_channel_post=message))
 
     def test_multiple_flags_deprecated(self, message):
-        handler = MessageHandler(None, self.callback_basic, edited_updates=True,
-                                 message_updates=True, channel_post_updates=True)
+        handler = MessageHandler(
+            None,
+            self.callback_basic,
+            edited_updates=True,
+            message_updates=True,
+            channel_post_updates=True,
+        )
 
         assert handler.check_update(Update(0, edited_message=message))
         assert handler.check_update(Update(0, message=message))
@@ -149,8 +190,13 @@ class TestMessageHandler:
 
     def test_none_allowed_deprecated(self):
         with pytest.raises(ValueError, match='are all False'):
-            MessageHandler(None, self.callback_basic, message_updates=False,
-                           channel_post_updates=False, edited_updates=False)
+            MessageHandler(
+                None,
+                self.callback_basic,
+                message_updates=False,
+                channel_post_updates=False,
+                edited_updates=False,
+            )
 
     def test_with_filter(self, message):
         handler = MessageHandler(Filters.group, self.callback_basic)
@@ -161,10 +207,28 @@ class TestMessageHandler:
         message.chat.type = 'private'
         assert not handler.check_update(Update(0, message))
 
+    def test_callback_query_with_filter(self, message):
+        class TestFilter(UpdateFilter):
+            flag = False
+
+            def filter(self, u):
+                self.flag = True
+
+        test_filter = TestFilter()
+        handler = MessageHandler(test_filter, self.callback_basic)
+
+        update = Update(1, callback_query=CallbackQuery(1, None, None, message=message))
+
+        assert update.effective_message
+        assert not handler.check_update(update)
+        assert not test_filter.flag
+
     def test_specific_filters(self, message):
-        f = (~Filters.update.messages
-             & ~Filters.update.channel_post
-             & Filters.update.edited_channel_post)
+        f = (
+            ~Filters.update.messages
+            & ~Filters.update.channel_post
+            & Filters.update.edited_channel_post
+        )
         handler = MessageHandler(f, self.callback_basic)
 
         assert not handler.check_update(Update(0, edited_message=message))
@@ -173,16 +237,14 @@ class TestMessageHandler:
         assert handler.check_update(Update(0, edited_channel_post=message))
 
     def test_pass_user_or_chat_data(self, dp, message):
-        handler = MessageHandler(None, self.callback_data_1,
-                                 pass_user_data=True)
+        handler = MessageHandler(None, self.callback_data_1, pass_user_data=True)
         dp.add_handler(handler)
 
         dp.process_update(Update(0, message=message))
         assert self.test_flag
 
         dp.remove_handler(handler)
-        handler = MessageHandler(None, self.callback_data_1,
-                                 pass_chat_data=True)
+        handler = MessageHandler(None, self.callback_data_1, pass_chat_data=True)
         dp.add_handler(handler)
 
         self.test_flag = False
@@ -190,8 +252,9 @@ class TestMessageHandler:
         assert self.test_flag
 
         dp.remove_handler(handler)
-        handler = MessageHandler(None, self.callback_data_2,
-                                 pass_chat_data=True, pass_user_data=True)
+        handler = MessageHandler(
+            None, self.callback_data_2, pass_chat_data=True, pass_user_data=True
+        )
         dp.add_handler(handler)
 
         self.test_flag = False
@@ -199,16 +262,14 @@ class TestMessageHandler:
         assert self.test_flag
 
     def test_pass_job_or_update_queue(self, dp, message):
-        handler = MessageHandler(None, self.callback_queue_1,
-                                 pass_job_queue=True)
+        handler = MessageHandler(None, self.callback_queue_1, pass_job_queue=True)
         dp.add_handler(handler)
 
         dp.process_update(Update(0, message=message))
         assert self.test_flag
 
         dp.remove_handler(handler)
-        handler = MessageHandler(None, self.callback_queue_1,
-                                 pass_update_queue=True)
+        handler = MessageHandler(None, self.callback_queue_1, pass_update_queue=True)
         dp.add_handler(handler)
 
         self.test_flag = False
@@ -216,8 +277,9 @@ class TestMessageHandler:
         assert self.test_flag
 
         dp.remove_handler(handler)
-        handler = MessageHandler(None, self.callback_queue_2,
-                                 pass_job_queue=True, pass_update_queue=True)
+        handler = MessageHandler(
+            None, self.callback_queue_2, pass_job_queue=True, pass_update_queue=True
+        )
         dp.add_handler(handler)
 
         self.test_flag = False
@@ -229,8 +291,9 @@ class TestMessageHandler:
         assert not handler.check_update(false_update)
 
     def test_context(self, cdp, message):
-        handler = MessageHandler(None, self.callback_context,
-                                 edited_updates=True, channel_post_updates=True)
+        handler = MessageHandler(
+            None, self.callback_context, edited_updates=True, channel_post_updates=True
+        )
         cdp.add_handler(handler)
 
         cdp.process_update(Update(0, message=message))
@@ -261,8 +324,9 @@ class TestMessageHandler:
         assert self.test_flag
 
     def test_context_multiple_regex(self, cdp, message):
-        handler = MessageHandler(Filters.regex('one') & Filters.regex('two'),
-                                 self.callback_context_regex2)
+        handler = MessageHandler(
+            Filters.regex('one') & Filters.regex('two'), self.callback_context_regex2
+        )
         cdp.add_handler(handler)
 
         message.text = 'not it'
