@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -20,20 +20,18 @@ import os
 
 import pytest
 
-
-def call_pre_commit_hook(hook_id):
-    __tracebackhide__ = True
-    return os.system(' '.join(['pre-commit', 'run', '--all-files', hook_id]))  # pragma: no cover
+from tests.conftest import env_var_2_bool
 
 
-@pytest.mark.nocoverage
-@pytest.mark.parametrize('hook_id', argvalues=('yapf', 'flake8', 'pylint'))
-@pytest.mark.skipif(not os.getenv('TEST_PRE_COMMIT', False), reason='TEST_PRE_COMMIT not enabled')
-def test_pre_commit_hook(hook_id):
-    assert call_pre_commit_hook(hook_id) == 0  # pragma: no cover
-
-
-@pytest.mark.nocoverage
-@pytest.mark.skipif(not os.getenv('TEST_BUILD', False), reason='TEST_BUILD not enabled')
+@pytest.mark.skipif(
+    not env_var_2_bool(os.getenv('TEST_BUILD', False)), reason='TEST_BUILD not enabled'
+)
 def test_build():
     assert os.system('python setup.py bdist_dumb') == 0  # pragma: no cover
+
+
+@pytest.mark.skipif(
+    not env_var_2_bool(os.getenv('TEST_BUILD', False)), reason='TEST_BUILD not enabled'
+)
+def test_build_raw():
+    assert os.system('python setup-raw.py bdist_dumb') == 0  # pragma: no cover
