@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2020
+# Copyright (C) 2015-2021
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,12 +17,15 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import os
+from pathlib import Path
 
 import pytest
 from flaky import flaky
 
-from telegram import Audio, Voice, TelegramError
+from telegram import Audio, Voice, TelegramError, MessageEntity, Bot
+from telegram.error import BadRequest
 from telegram.utils.helpers import escape_markdown
+from tests.conftest import check_shortcut_call, check_shortcut_signature, check_defaults_handling
 
 
 @pytest.fixture(scope='function')
@@ -43,7 +46,7 @@ class TestVoice:
     mime_type = 'audio/ogg'
     file_size = 9199
 
-    caption = u'Test *voice*'
+    caption = 'Test *voice*'
     voice_file_url = 'https://python-telegram-bot.org/static/testfiles/telegram.ogg'
 
     voice_file_id = '5a3128a4d2a04750b5b58397f3b5e812'
@@ -65,9 +68,14 @@ class TestVoice:
     @flaky(3, 1)
     @pytest.mark.timeout(10)
     def test_send_all_args(self, bot, chat_id, voice_file, voice):
-        message = bot.send_voice(chat_id, voice_file, duration=self.duration,
-                                 caption=self.caption, disable_notification=False,
-                                 parse_mode='Markdown')
+        message = bot.send_voice(
+            chat_id,
+            voice_file,
+            duration=self.duration,
+            caption=self.caption,
+            disable_notification=False,
+            parse_mode='Markdown',
+        )
 
         assert isinstance(message.voice, Voice)
         assert isinstance(message.voice.file_id, str)
@@ -79,6 +87,16 @@ class TestVoice:
         assert message.voice.file_size == voice.file_size
         assert message.caption == self.caption.replace('*', '')
 
+    @flaky(3, 1)
+    @pytest.mark.timeout(10)
+    def test_send_voice_custom_filename(self, bot, chat_id, voice_file, monkeypatch):
+        def make_assertion(url, data, **kwargs):
+            return data['voice'].filename == 'custom_filename'
+
+        monkeypatch.setattr(bot.request, 'post', make_assertion)
+
+        assert bot.send_voice(chat_id, voice_file, filename='custom_filename')
+
     @flaky(3, 1)
     @pytest.mark.timeout(10)
     def test_get_and_download(self, bot, voice):
@@ -115,13 +133,29 @@ class TestVoice:
         assert message.voice == voice
 
     def test_send_with_voice(self, monkeypatch, bot, chat_id, voice):
-        def test(_, url, data, **kwargs):
+        def test(url, data, **kwargs):
             return data['voice'] == voice.file_id
 
-        monkeypatch.setattr('telegram.utils.request.Request.post', test)
+        monkeypatch.setattr(bot.request, 'post', test)
         message = bot.send_voice(chat_id, voice=voice)
         assert message
 
+    @flaky(3, 1)
+    @pytest.mark.timeout(10)
+    def test_send_voice_caption_entities(self, bot, chat_id, voice_file):
+        test_string = 'Italic Bold Code'
+        entities = [
+            MessageEntity(MessageEntity.ITALIC, 0, 6),
+            MessageEntity(MessageEntity.ITALIC, 7, 4),
+            MessageEntity(MessageEntity.ITALIC, 12, 4),
+        ]
+        message = bot.send_voice(
+            chat_id, voice_file, caption=test_string, caption_entities=entities
+        )
+
+        assert message.caption == test_string
+        assert message.caption_entities == entities
+
     @flaky(3, 1)
     @pytest.mark.timeout(10)
     @pytest.mark.parametrize('default_bot', [{'parse_mode': 'Markdown'}], indirect=True)
@@ -139,8 +173,9 @@ class TestVoice:
     def test_send_voice_default_parse_mode_2(self, default_bot, chat_id, voice):
         test_markdown_string = '_Italic_ *Bold* `Code`'
 
-        message = default_bot.send_voice(chat_id, voice, caption=test_markdown_string,
-                                         parse_mode=None)
+        message = default_bot.send_voice(
+            chat_id, voice, caption=test_markdown_string, parse_mode=None
+        )
         assert message.caption == test_markdown_string
         assert message.caption_markdown == escape_markdown(test_markdown_string)
 
@@ -150,11 +185,61 @@ class TestVoice:
     def test_send_voice_default_parse_mode_3(self, default_bot, chat_id, voice):
         test_markdown_string = '_Italic_ *Bold* `Code`'
 
-        message = default_bot.send_voice(chat_id, voice, caption=test_markdown_string,
-                                         parse_mode='HTML')
+        message = default_bot.send_voice(
+            chat_id, voice, caption=test_markdown_string, parse_mode='HTML'
+        )
         assert message.caption == test_markdown_string
         assert message.caption_markdown == escape_markdown(test_markdown_string)
 
+    def test_send_voice_local_files(self, monkeypatch, bot, chat_id):
+        # For just test that the correct paths are passed as we have no local bot API set up
+        test_flag = False
+        expected = (Path.cwd() / 'tests/data/telegram.jpg/').as_uri()
+        file = 'tests/data/telegram.jpg'
+
+        def make_assertion(_, data, *args, **kwargs):
+            nonlocal test_flag
+            test_flag = data.get('voice') == expected
+
+        monkeypatch.setattr(bot, '_post', make_assertion)
+        bot.send_voice(chat_id, file)
+        assert test_flag
+
+    @flaky(3, 1)
+    @pytest.mark.timeout(10)
+    @pytest.mark.parametrize(
+        'default_bot,custom',
+        [
+            ({'allow_sending_without_reply': True}, None),
+            ({'allow_sending_without_reply': False}, None),
+            ({'allow_sending_without_reply': False}, True),
+        ],
+        indirect=['default_bot'],
+    )
+    def test_send_voice_default_allow_sending_without_reply(
+        self, default_bot, chat_id, voice, custom
+    ):
+        reply_to_message = default_bot.send_message(chat_id, 'test')
+        reply_to_message.delete()
+        if custom is not None:
+            message = default_bot.send_voice(
+                chat_id,
+                voice,
+                allow_sending_without_reply=custom,
+                reply_to_message_id=reply_to_message.message_id,
+            )
+            assert message.reply_to_message is None
+        elif default_bot.defaults.allow_sending_without_reply:
+            message = default_bot.send_voice(
+                chat_id, voice, reply_to_message_id=reply_to_message.message_id
+            )
+            assert message.reply_to_message is None
+        else:
+            with pytest.raises(BadRequest, match='message not found'):
+                default_bot.send_voice(
+                    chat_id, voice, reply_to_message_id=reply_to_message.message_id
+                )
+
     def test_de_json(self, bot):
         json_dict = {
             'file_id': self.voice_file_id,
@@ -162,7 +247,7 @@ class TestVoice:
             'duration': self.duration,
             'caption': self.caption,
             'mime_type': self.mime_type,
-            'file_size': self.file_size
+            'file_size': self.file_size,
         }
         json_voice = Voice.de_json(json_dict, bot)
 
@@ -199,10 +284,14 @@ class TestVoice:
             bot.sendVoice(chat_id)
 
     def test_get_file_instance_method(self, monkeypatch, voice):
-        def test(*args, **kwargs):
-            return args[1] == voice.file_id
+        def make_assertion(*_, **kwargs):
+            return kwargs['file_id'] == voice.file_id
 
-        monkeypatch.setattr('telegram.Bot.get_file', test)
+        assert check_shortcut_signature(Voice.get_file, Bot.get_file, ['file_id'], [])
+        assert check_shortcut_call(voice.get_file, voice.bot, 'get_file')
+        assert check_defaults_handling(voice.get_file, voice.bot)
+
+        monkeypatch.setattr(voice.bot, 'get_file', make_assertion)
         assert voice.get_file()
 
     def test_equality(self, voice):
